@@ -21,7 +21,7 @@
 #include <net-snmp/agent/scalar.h>
 
 #include <stdlib.h>
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
