@@ -17,7 +17,7 @@
 
 #include <net-snmp/agent/table_data.h>
 
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
