@@ -255,7 +255,7 @@ ROWAPI_new(TABLE_DEFINTION_T * table_ptr, u_long ctrl_index)
 
 void
 ROWAPI_init_table(TABLE_DEFINTION_T * table_ptr,
-                  char *name,
+                  const char *name,
                   u_long max_number_of_entries,
                   ENTRY_CALLBACK_T * ClbkCreate,
                   ENTRY_CALLBACK_T * ClbkClone,
