@@ -1,18 +1,18 @@
 #ifndef DELIVERBYNOTIFY_H
 #define DELIVERBYNOTIFY_H 1
 
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
 # endif
 #endif
 
-config_add_mib(NET-SNMP-PERIODIC-NOTIFY-MIB)
+config_add_mib(NET-SNMP-PERIODIC-NOTIFY-MIB);
 
 void init_deliverByNotify(void);
 
