@@ -311,7 +311,7 @@ mteObjects_vblist( netsnmp_variable_list *vblist,
     while (row && !netsnmp_tdata_compare_subtree_idx( row, &owner_var )) {
         entry = (struct mteObject *)netsnmp_tdata_row_entry(row);
 
-        memset(name, 0, MAX_OID_LEN);
+        memset(name, 0, sizeof(name));
         memcpy(name, entry->mteObjectID,
                      entry->mteObjectID_len*sizeof(oid));
         name_len = entry->mteObjectID_len;
