@@ -16,10 +16,10 @@
 /*
  * This should always be included first before anything else 
  */
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
@@ -61,27 +61,24 @@ struct variable2 pingProbeHistoryTable_variables[] = {
 };
 
 
-/*
- * global storage of our data, saved in and configured by header_complex() 
- */
-
-extern struct header_complex_index *pingCtlTableStorage;
-extern struct header_complex_index *pingProbeHistoryTableStorage;
 int
 pingProbeHistoryTable_inadd(struct pingProbeHistoryTable_data *thedata);
 
+#if 0
 void
 pingProbeHistoryTable_cleaner(struct header_complex_index *thestuff)
 {
-    struct header_complex_index *hciptr = NULL;
+    struct header_complex_index *hciptr, *nhciptr;
 
     DEBUGMSGTL(("pingProbeHistoryTable", "cleanerout  "));
-    for (hciptr = thestuff; hciptr != NULL; hciptr = hciptr->next) {
+    for (hciptr = thestuff; hciptr; hciptr = nhciptr) {
+        nhciptr = hciptr->next;
         header_complex_extract_entry(&pingProbeHistoryTableStorage, hciptr);
         DEBUGMSGTL(("pingProbeHistoryTable", "cleaner  "));
     }
-
 }
+#endif
+
 void
 init_pingProbeHistoryTable(void)
 {
@@ -137,6 +134,7 @@ parse_pingProbeHistoryTable(const char *token, char *line)
                               &StorageTmp->pingCtlOwnerIndexLen);
     if (StorageTmp->pingCtlOwnerIndex == NULL) {
         config_perror("invalid specification for pingCtlOwnerIndex");
+        free(StorageTmp);
         return;
     }
 
@@ -146,6 +144,7 @@ parse_pingProbeHistoryTable(const char *token, char *line)
                               &StorageTmp->pingCtlTestNameLen);
     if (StorageTmp->pingCtlTestName == NULL) {
         config_perror("invalid specification for pingCtlTestName");
+        free(StorageTmp);
         return;
     }
 
@@ -171,6 +170,7 @@ parse_pingProbeHistoryTable(const char *token, char *line)
                               &StorageTmp->pingProbeHistoryTimeLen);
     if (StorageTmp->pingProbeHistoryTime == NULL) {
         config_perror("invalid specification for pingProbeHistoryTime");
+        free(StorageTmp);
         return;
     }
 
