@@ -6,27 +6,33 @@
 #include "hardware/fsys/hw_fsys_private.h"
 
 #include <stdio.h>
-#if HAVE_MNTENT_H
+#ifdef HAVE_MNTENT_H
 #include <mntent.h>
 #endif
 #ifdef HAVE_SYS_MNTTAB_H
 #include <sys/mnttab.h>
 #endif
-#if HAVE_SYS_VFS_H
+#ifdef HAVE_SYS_VFS_H
 #include <sys/vfs.h>
 #endif
-#if HAVE_SYS_PARAM_H
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
-#if HAVE_SYS_MOUNT_H
+#ifdef HAVE_SYS_MOUNT_H
 #include <sys/mount.h>
 #endif
-#if HAVE_SYS_STATFS_H
+#ifdef HAVE_SYS_STATFS_H
 #include <sys/statfs.h>
 #endif
-#if HAVE_SYS_STATVFS_H
+#ifdef HAVE_SYS_STATVFS_H
 #include <sys/statvfs.h>
 #endif
+#if defined(HAVE_PCRE_H)
+#include <pcre.h>
+#elif defined(HAVE_REGEX_H)
+#include <sys/types.h>
+#include <regex.h>
+#endif
 
 #ifdef solaris2
 #define _NETSNMP_GETMNTENT_TWO_ARGS 1
@@ -83,6 +89,7 @@ static const char *other_fs[] = {
     "reiserfs",
     "simfs",
     "tmpfs",
+    "virtiofs",
     "vxfs",
     "xfs",
     "zfs",
@@ -179,6 +186,44 @@ netsnmp_fsys_arch_init( void )
     return;
 }
 
+static int
+ignore_mount_point(const char *name)
+{
+    conf_mount_list *m_ptr;
+#ifdef HAVE_PCRE_H
+    int                      found_ndx[3];
+#endif
+
+    if (!ignoremount_list)
+        return FALSE;
+
+    for (m_ptr = ignoremount_list; m_ptr; m_ptr = m_ptr->next) {
+#if defined(HAVE_PCRE_H)
+        if (m_ptr->regex_ptr) {
+            if (pcre_exec(m_ptr->regex_ptr, NULL, name, strlen(name), 0, 0,
+                found_ndx, 3) >= 0)
+                return TRUE;
+        } else {
+            if (strcmp(name, m_ptr->name) == 0)
+                return TRUE;
+        }
+#elif defined(HAVE_REGEX_H)
+        if (m_ptr->regex_ptr) {
+            if (regexec(m_ptr->regex_ptr, name, 0, NULL, 0) == 0)
+                return TRUE;
+        } else {
+            if (strcmp(name, m_ptr->name) == 0)
+                return TRUE;
+        }
+#else
+        if (strcmp(name, m_ptr->name) == 0)
+            return TRUE;
+#endif
+    }
+
+    return FALSE;
+}
+
 void
 netsnmp_fsys_arch_load( void )
 {
@@ -247,6 +292,12 @@ netsnmp_fsys_arch_load( void )
          *  XXX - identify removeable disks
          */
 
+        /*
+         *  Skip ignored mount points
+         */
+        if (ignore_mount_point(entry->path))
+            continue;
+
         /*
          *  Optionally skip retrieving statistics for remote mounts
          */
