@@ -5,10 +5,10 @@
 #include <net-snmp/net-snmp-config.h>
 
 #include <sys/types.h>
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
@@ -18,6 +18,13 @@
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 #include "header_complex.h"
 
+#include <net-snmp/net-snmp-features.h>
+
+netsnmp_feature_child_of(header_complex_all, libnetsnmpmibs);
+
+netsnmp_feature_child_of(header_complex_free_all, header_complex_all);
+netsnmp_feature_child_of(header_complex_find_entry, header_complex_all);
+
 int
 header_complex_generate_varoid(netsnmp_variable_list * var)
 {
@@ -337,8 +344,9 @@ header_complex(struct header_complex_index *datalist,
 }
 
 struct header_complex_index *
-header_complex_add_data(struct header_complex_index **thedata,
-                        netsnmp_variable_list * var, void *data)
+header_complex_maybe_add_data(struct header_complex_index **thedata,
+                              netsnmp_variable_list * var, void *data,
+                              int dont_allow_duplicates)
 {
     oid             newoid[MAX_OID_LEN];
     size_t          newoid_len;
@@ -349,7 +357,8 @@ header_complex_add_data(struct header_complex_index **thedata,
 
     header_complex_generate_oid(newoid, &newoid_len, NULL, 0, var);
     ret =
-        header_complex_add_data_by_oid(thedata, newoid, newoid_len, data);
+        header_complex_maybe_add_data_by_oid(thedata, newoid, newoid_len, data,
+                                             dont_allow_duplicates);
     /*
      * free the variable list, but not the enclosed data!  it's not ours! 
      */
@@ -358,34 +367,21 @@ header_complex_add_data(struct header_complex_index **thedata,
 }
 
 struct header_complex_index *
-header_complex_add_data_by_oid(struct header_complex_index **thedata,
-                               oid * newoid, size_t newoid_len, void *data)
+header_complex_add_data(struct header_complex_index **thedata,
+                        netsnmp_variable_list * var, void *data)
 {
-    struct header_complex_index *hciptrn, *hciptrp, *ourself;
-    int rc;
+    return
+        header_complex_maybe_add_data(thedata, var, data, 0);
+}
 
-    if (thedata == NULL || newoid == NULL || data == NULL)
-        return NULL;
 
-    for (hciptrn = *thedata, hciptrp = NULL;
-         hciptrn != NULL; hciptrp = hciptrn, hciptrn = hciptrn->next) {
-        /*
-         * XXX: check for == and error (overlapping table entries) 
-         * 8/2005 rks Ok, I added duplicate entry check, but only log
-         *            warning and continue, because it seems that nobody
-         *            that calls this fucntion does error checking!.
-         */
-        rc = snmp_oid_compare(hciptrn->name, hciptrn->namelen,
-                              newoid, newoid_len);
-        if (rc > 0)
-            break;
-        else if (0 == rc) {
-            snmp_log(LOG_WARNING, "header_complex_add_data_by_oid with "
-                     "duplicate index.\n");
-            /** uncomment null return when callers do error checking */
-            /** return NULL; */
-        }
-    }
+struct header_complex_index *
+_header_complex_add_between(struct header_complex_index **thedata,
+                            struct header_complex_index *hciptrp,
+                            struct header_complex_index *hciptrn,
+                            oid * newoid, size_t newoid_len, void *data)
+{
+    struct header_complex_index *ourself;
 
     /*
      * nptr should now point to the spot that we need to add ourselves
@@ -429,6 +425,50 @@ header_complex_add_data_by_oid(struct header_complex_index **thedata,
     return hciptrp;
 }
 
+
+struct header_complex_index *
+header_complex_maybe_add_data_by_oid(struct header_complex_index **thedata,
+                                     oid * newoid, size_t newoid_len, void *data,
+                                     int dont_allow_duplicates)
+{
+    struct header_complex_index *hciptrn, *hciptrp;
+    int rc;
+
+    if (thedata == NULL || newoid == NULL || data == NULL)
+        return NULL;
+
+    for (hciptrn = *thedata, hciptrp = NULL;
+         hciptrn != NULL; hciptrp = hciptrn, hciptrn = hciptrn->next) {
+        /*
+         * XXX: check for == and error (overlapping table entries) 
+         * 8/2005 rks Ok, I added duplicate entry check, but only log
+         *            warning and continue, because it seems that nobody
+         *            that calls this fucntion does error checking!.
+         */
+        rc = snmp_oid_compare(hciptrn->name, hciptrn->namelen,
+                              newoid, newoid_len);
+        if (rc > 0)
+            break;
+        else if (0 == rc) {
+            snmp_log(LOG_WARNING, "header_complex_add_data_by_oid with "
+                     "duplicate index.\n");
+            if (dont_allow_duplicates)
+                return NULL;
+        }
+    }
+
+    return _header_complex_add_between(thedata, hciptrp, hciptrn,
+                                       newoid, newoid_len, data);
+}
+
+struct header_complex_index *
+header_complex_add_data_by_oid(struct header_complex_index **thedata,
+                               oid * newoid, size_t newoid_len, void *data)
+{
+    return header_complex_maybe_add_data_by_oid(thedata, newoid, newoid_len,
+                                                data, 0);
+}
+
 /*
  * extracts an entry from the storage space (removing it from future
  * accesses) and returns the data stored there
@@ -485,6 +525,7 @@ header_complex_free_entry(struct header_complex_index *theentry,
 /*
  * completely wipe out all entries in our data store 
  */
+#ifndef NETSNMP_FEATURE_REMOVE_HEADER_COMPLEX_FREE_ALL
 void
 header_complex_free_all(struct header_complex_index *thestuff,
                         HeaderComplexCleaner * cleaner)
@@ -496,7 +537,9 @@ header_complex_free_all(struct header_complex_index *thestuff,
         header_complex_free_entry(hciptr, cleaner);
     }
 }
+#endif /* NETSNMP_FEATURE_REMOVE_HEADER_COMPLEX_FREE_ALL */
 
+#ifndef NETSNMP_FEATURE_REMOVE_HEADER_COMPLEX_FIND_ENTRY
 struct header_complex_index *
 header_complex_find_entry(struct header_complex_index *thestuff,
                           void *theentry)
@@ -507,6 +550,7 @@ header_complex_find_entry(struct header_complex_index *thestuff,
          hciptr = hciptr->next);
     return hciptr;
 }
+#endif /* NETSNMP_FEATURE_REMOVE_HEADER_COMPLEX_FIND_ENTRY */
 
 #ifdef TESTING
 
@@ -525,7 +569,7 @@ header_complex_dump(struct header_complex_index *thestuff)
     }
 }
 
-main()
+int main(void)
 {
     oid             oidsave[MAX_OID_LEN];
     int             len = MAX_OID_LEN, len2;
