@@ -14,22 +14,22 @@
 /*
  * all platforms use this generic code
  */
-config_exclude(host/hr_swinst)
+config_exclude(host/hr_swinst);
 
 /*
  * select the appropriate architecture-specific interface code
  */
 #if   defined( darwin )
-    config_require(host/data_access/swinst_darwin)
+    config_require(host/data_access/swinst_darwin);
 #elif defined( HAVE_DPKG_QUERY )
-    config_require(host/data_access/swinst_apt)
+    config_require(host/data_access/swinst_apt);
 #elif defined( HAVE_LIBRPM ) && defined( linux )
-    config_require(host/data_access/swinst_rpm)
+    config_require(host/data_access/swinst_rpm);
 #elif defined( HAVE_PKGLOCS_H ) || defined( hpux9 ) || defined( hpux10 ) || defined( hpux11 ) || defined( freebsd2 ) || defined( linux ) || defined( openbsd )
-    config_require(host/data_access/swinst_pkginfo)
+    config_require(host/data_access/swinst_pkginfo);
 #else
-    config_warning(This platform does not yet support hrSWInstalledTable rewrites)
-    config_require(host/data_access/swinst_null)
+    config_warning(This platform does not yet support hrSWInstalledTable rewrites);
+    config_require(host/data_access/swinst_null);
 #endif
 
 void init_swinst( void );
