@@ -1,7 +1,7 @@
 /*
  * ioctl interface data access header
  *
- * $Id: interface_ioctl.h 13309 2005-10-29 03:30:43Z rstory $
+ * $Id$
  */
 #ifndef NETSNMP_ACCESS_INTERFACE_IOCTL_H
 #define NETSNMP_ACCESS_INTERFACE_IOCTL_H
@@ -9,7 +9,7 @@
 /*
  * need ipaddress functions to get ipversions of an interface
 */
-config_require(ip-mib/data_access/ipaddress)
+config_require(ip-mib/data_access/ipaddress);
 
 #ifdef __cplusplus
 extern          "C" {
@@ -18,10 +18,17 @@ extern          "C" {
 /**---------------------------------------------------------------------*/
 /**/
 
+int
+netsnmp_convert_arphrd_type(int arphrd_type);
+
 int
 netsnmp_access_interface_ioctl_physaddr_get(int fd,
                                             netsnmp_interface_entry *ifentry);
 
+void
+netsnmp_process_link_flags(netsnmp_interface_entry *ifentry,
+                           unsigned int os_flags);
+
 int
 netsnmp_access_interface_ioctl_flags_get(int fd,
                                          netsnmp_interface_entry *ifentry);
@@ -41,7 +48,8 @@ netsnmp_access_interface_ioctl_ifindex_get(int fd, const char *name);
 
 int
 netsnmp_access_interface_ioctl_has_ipv4(int sd, const char *if_name,
-                                        int if_index, u_int *flags);
+                                        int if_index, u_int *flags,
+                                        const struct ifconf *pifc);
 
 /**---------------------------------------------------------------------*/
 
