@@ -2,5 +2,5 @@
  * module to include the modules
  */
 
-config_require(if-mib/ifXTable/ifXTable)
+config_require(if-mib/ifXTable/ifXTable);
 
