@@ -97,9 +97,7 @@ _load_ipv4(netsnmp_container* container, u_long *index )
             snmp_log(LOG_ERR,
                      "/proc/net/route data format error (%d!=8), line ==|%s|",
                      rc, line);
-            
-            netsnmp_access_route_entry_free(entry);        
-            continue;
+            goto free_entry;
         }
 
         /*
@@ -114,9 +112,12 @@ _load_ipv4(netsnmp_container* container, u_long *index )
          * but since that will open/close a socket, and we might
          * have a lot of routes, call the ioctl routine directly.
          */
-        if ('*' != name[0])
+        if ('*' != name[0]) {
             entry->if_index =
                 netsnmp_access_interface_ioctl_ifindex_get(fd,name);
+            if (entry->if_index == 0)
+                goto free_entry;
+        }
 
         /*
          * arbitrary index
@@ -186,8 +187,8 @@ _load_ipv4(netsnmp_container* container, u_long *index )
         if (CONTAINER_INSERT(container, entry) < 0)
         {
             DEBUGMSGTL(("access:route:container", "error with route_entry: insert into container failed.\n"));
+free_entry:
             netsnmp_access_route_entry_free(entry);
-            continue;
         }
     }
 
