@@ -17,16 +17,16 @@
  *    HPUX11 had different reuirements than other HPUX, that should
  *    be handled in the *_hpux.h header file.
  */
-config_require(ip-mib/data_access/defaultrouter_common)
+config_require(ip-mib/data_access/defaultrouter_common);
 #if defined( linux )
-config_require(ip-mib/data_access/defaultrouter_linux)
+config_require(ip-mib/data_access/defaultrouter_linux);
 #elif defined( freebsd4 ) || defined( netbsd5 ) || defined( openbsd ) || defined( dragonfly ) || defined( darwin )
-config_require(ip-mib/data_access/defaultrouter_sysctl)
+config_require(ip-mib/data_access/defaultrouter_sysctl);
 #elif defined( solaris2 )
-config_require(ip-mib/data_access/defaultrouter_solaris2)
+config_require(ip-mib/data_access/defaultrouter_solaris2);
 #else
 /*
  * couldn't determine the correct file!
  */
-config_error(the defaultrouter data access library is not available in this environment.)
+config_error(the defaultrouter data access library is not available in this environment.);
 #endif
