@@ -163,7 +163,7 @@ _load_defaultrouter_from_sysctl(netsnmp_container *container, int family)
     lim = buf + needed;
     for (next = buf; next < lim; next += rtm->rtm_msglen) {
 #ifdef NETSNMP_ENABLE_IPV6
-	struct in6_addr in6addr_any = IN6ADDR_ANY_INIT;
+	struct in6_addr in6addr_any = { } /*IN6ADDR_ANY_INIT*/;
 #endif
 
         rtm = (struct rt_msghdr *)next;
