@@ -19,6 +19,7 @@
 
 #include <errno.h>
 #include <sys/ioctl.h>
+#include <sys/stat.h>
 
 netsnmp_feature_require(prefix_info);
 netsnmp_feature_require(find_prefix_info);
@@ -29,7 +30,6 @@ netsnmp_feature_child_of(ipaddress_arch_entry_copy, ipaddress_common);
 netsnmp_feature_require(ipaddress_ioctl_entry_copy);
 #endif /* NETSNMP_FEATURE_REQUIRE_IPADDRESS_ARCH_ENTRY_COPY */
 
-#if defined (NETSNMP_ENABLE_IPV6)
 #include <linux/types.h>
 #include <asm/types.h>
 #if defined(HAVE_LINUX_RTNETLINK_H)
@@ -39,7 +39,6 @@ netsnmp_feature_require(ipaddress_ioctl_entry_copy);
 #define SUPPORT_PREFIX_FLAGS 1
 #endif /* RTMGRP_IPV6_PREFIX */
 #endif /* HAVE_LINUX_RTNETLINK_H */
-#endif
 
 #include "ipaddress.h"
 #include "ipaddress_ioctl.h"
@@ -219,7 +218,7 @@ _load_v6(netsnmp_container *container, int idx_offset)
                 "cannot get ip address information"
                 "as netlink socket is not available\n"));
     return -1;
-#else
+#else /* HAVE_LINUX_RTNETLINK_H */
     FILE           *in;
     char            line[80], addr[40];
     char            if_name[IFNAMSIZ+1];/* +1 for '\0' because of the ugly sscanf below */ 
@@ -234,7 +233,18 @@ _load_v6(netsnmp_container *container, int idx_offset)
 
 #define PROCFILE "/proc/net/if_inet6"
     if (!(in = fopen(PROCFILE, "r"))) {
-        NETSNMP_LOGONCE((LOG_ERR, "ipaddress_linux: could not open " PROCFILE));
+        /*
+         * If opening /proc/net/if_inet6 fails, only complain if that file
+         * does not exist. If it exists but if it is not readable, do not
+         * log an error message because this probably is the result of IPv6
+         * support having been disabled intentionally.
+         */
+        struct stat st;
+
+        if (stat(PROCFILE, &st) == 0) {
+            NETSNMP_LOGONCE((LOG_ERR,
+                             "ipaddress_linux: could not open " PROCFILE));
+        }
         return -2;
     }
 
@@ -418,8 +428,10 @@ _load_v6(netsnmp_container *container, int idx_offset)
         return rc;
 
     return idx_offset;
+#endif /* HAVE_LINUX_RTNETLINK_H */
 }
 
+#ifdef HAVE_LINUX_RTNETLINK_H
 struct address_flag_info
 netsnmp_access_other_info_get(int index, int family)
 {
@@ -507,10 +519,8 @@ netsnmp_access_other_info_get(int index, int family)
 out:
     close(sd);
     return addr;
-#endif
 }
 
-#ifdef HAVE_LINUX_RTNETLINK_H
 int
 netsnmp_access_ipaddress_extra_prefix_info(int index, u_long *preferedlt,
                                            ulong *validlt, char *addr)
@@ -609,6 +619,5 @@ out:
     close(sd);
     return ret;
 }
-#endif
-#endif
-
+#endif /* HAVE_LINUX_RTNETLINK_H */
+#endif /* defined(NETSNMP_ENABLE_IPV6) */
