@@ -1,7 +1,7 @@
 /*
  * ipaddress data access header
  *
- * $Id: ipaddress_linux.h 19133 2010-06-29 22:18:49Z magfr $
+ * $Id$
  */
 /**---------------------------------------------------------------------*/
 /*
@@ -17,5 +17,5 @@
  *    HPUX11 had different reuirements than other HPUX, that should
  *    be handled in the *_hpux.h header file.
  */
-config_require(ip-mib/data_access/ipaddress_ioctl)
-config_require(util_funcs)
+config_require(ip-mib/data_access/ipaddress_ioctl);
+config_require(util_funcs);
