@@ -14,6 +14,7 @@
 #include "systemstats_private.h"
 
 #include <sys/types.h>
+#include <unistd.h>
 #include <dirent.h>
 #include <ctype.h>
 
@@ -25,7 +26,7 @@
 #define _KERNEL 1
 #define _I_DEFINED_KERNEL
 #endif
-#if NETSNMP_IFNET_NEEDS_KERNEL_STRUCTURES
+#ifdef NETSNMP_IFNET_NEEDS_KERNEL_STRUCTURES
 #define _KERNEL_STRUCTURES
 #endif
 #include <net/if.h>
@@ -37,10 +38,10 @@
 #include <netinet/ip.h>
 #include <netinet/ip_icmp.h>
 #include <netinet/ip_var.h>
-#if HAVE_NETINET_ICMP6_H
+#ifdef HAVE_NETINET_ICMP6_H
 #include <netinet/icmp6.h>
 #endif
-#if HAVE_NETINET6_IP6_VAR_H
+#ifdef HAVE_NETINET6_IP6_VAR_H
 #include <sys/queue.h>
 #include <netinet6/ip6_var.h>
 #endif
@@ -586,7 +587,7 @@ _systemstats_v6_load_systemstats(netsnmp_container* container, u_int load_flags)
     entry->stats.InHdrErrors = ip6stat.ip6s_badoptions + ip6stat.ip6s_tooshort
                              + ip6stat.ip6s_toosmall + ip6stat.ip6s_badvers
 			     + ip6stat.ip6s_toomanyhdr;
-#if HAVE_STRUCT_IP6STAT_IP6S_EXTHDRTOOLONG
+#ifdef HAVE_STRUCT_IP6STAT_IP6S_EXTHDRTOOLONG
     entry->stats.InHdrErrors += ip6stat.ip6s_exthdrtoolong;
 #endif
     entry->stats.columnAvail[IPSYSTEMSTATSTABLE_INHDRERRORS] = 1;
@@ -693,7 +694,6 @@ _systemstats_v6_load_ifstats(netsnmp_container* container, u_int load_flags)
     FILE           *devin;
     char           line[1024];
     char           *start = line;
-    int            rc;
     char           *scan_str;
     uintmax_t       scan_val;
     netsnmp_systemstats_entry *entry = NULL;
@@ -711,7 +711,6 @@ _systemstats_v6_load_ifstats(netsnmp_container* container, u_int load_flags)
     /*
      * Read each per interface statistics proc file
      */
-    rc = 0;
     while ((dev_snmp6_entry = readdir(dev_snmp6_dir)) != NULL) {
         if (dev_snmp6_entry->d_name[0] == '.')
             continue;
