@@ -10,36 +10,39 @@
 #define _WANT_TCPCB 1
 #include <sys/types.h>
 #include <sys/socket.h>
-#if HAVE_SYS_IOCTL_H
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
 #endif
 #if defined(NETSNMP_IFNET_NEEDS_KERNEL) && !defined(_KERNEL)
 #define _KERNEL 1
 #define _I_DEFINED_KERNEL
 #endif
-#if NETSNMP_IFNET_NEEDS_KERNEL_STRUCTURES
+#ifdef NETSNMP_IFNET_NEEDS_KERNEL_STRUCTURES
 #define _KERNEL_STRUCTURES
 #endif
 #include <sys/param.h>
-#if HAVE_SYS_SOCKETVAR_H
+#ifdef _I_DEFINED_KERNEL
+#undef _KERNEL
+#endif
+#ifdef HAVE_SYS_SOCKETVAR_H
 # include <sys/socketvar.h>
 #endif
 
-#if STDC_HEADERS
+#ifdef STDC_HEADERS
 #include <string.h>
 #include <stdlib.h>
 #else
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
-#if HAVE_SYS_SYSCTL_H
+#ifdef HAVE_SYS_SYSCTL_H
 #ifdef _I_DEFINED_KERNEL
 #undef _KERNEL
 #endif
@@ -48,10 +51,10 @@
 #define _KERNEL 1
 #endif
 #endif
-#if HAVE_SYS_SYSMP_H
+#ifdef HAVE_SYS_SYSMP_H
 #include <sys/sysmp.h>
 #endif
-#if HAVE_SYS_TCPIPSTATS_H
+#ifdef HAVE_SYS_TCPIPSTATS_H
 #include <sys/tcpipstats.h>
 #endif
 #ifdef _I_DEFINED_KERNEL
@@ -61,10 +64,10 @@
 #ifdef _I_DEFINED_KERNEL
 #define _KERNEL 1
 #endif
-#if HAVE_NET_IF_VAR_H
+#ifdef HAVE_NET_IF_VAR_H
 #include <net/if_var.h>
 #endif
-#if HAVE_NET_IF_DL_H
+#ifdef HAVE_NET_IF_DL_H
 #include <net/if_dl.h>
 #endif
 #ifdef HAVE_NET_IF_MIB_H
@@ -74,79 +77,79 @@
 #undef _KERNEL
 #endif
 #include <netinet/in_systm.h>
-#if HAVE_SYS_HASHING_H
+#ifdef HAVE_SYS_HASHING_H
 #include <sys/hashing.h>
 #endif
-#if HAVE_SYS_SOCKIO_H
+#ifdef HAVE_SYS_SOCKIO_H
 #include <sys/sockio.h>
 #endif
-#if HAVE_NETINET6_IN6_VAR_H
+#ifdef HAVE_NETINET6_IN6_VAR_H
 #include <netinet6/in6_var.h>
 #endif
 #include <netinet/ip6.h>
-#if HAVE_NETINET_IP_VAR_H
+#ifdef HAVE_NETINET_IP_VAR_H
 # include <netinet/ip_var.h>
 #endif
-#if HAVE_NETINET_ICMP6_H
+#ifdef HAVE_NETINET_ICMP6_H
 # include <netinet/icmp6.h>
 #endif
-#if HAVE_NETINET6_IP6_VAR_H
+#ifdef HAVE_NETINET6_IP6_VAR_H
 # include <sys/queue.h>
 # include <netinet6/ip6_var.h>
 #endif
 #include <net/route.h>
-#if HAVE_NETINET_IP_H
+#ifdef HAVE_NETINET_IP_H
 # include <netinet/ip.h>
 #endif
-#if HAVE_NETINET_IN_PCB_H
+#ifdef HAVE_NETINET_IN_PCB_H
 # include <netinet/in_pcb.h>
 #endif
-#if HAVE_NETINET6_IN6_PCB_H
+#ifdef HAVE_NETINET6_IN6_PCB_H
 # include <netinet6/in6_pcb.h>
 #endif
-#if HAVE_NETINET6_TCP6_H
+#ifdef HAVE_NETINET6_TCP6_H
 # define TCP6
 #endif
 #ifndef TCP6
-# if HAVE_NETINET_TCP_H
+# ifdef HAVE_NETINET_TCP_H
 #  include <netinet/tcp.h>
 # endif
-# if HAVE_NETINET_TCP_TIMER_H
+# ifdef HAVE_NETINET_TCP_TIMER_H
 #  include <netinet/tcp_timer.h>
 # endif
-# if HAVE_NETINET_TCP_VAR_H
+# ifdef HAVE_NETINET_TCP_VAR_H
 #  include <netinet/tcp_var.h>
 # endif
-# if HAVE_NETINET_TCP_FSM_H
+# ifdef HAVE_NETINET_TCP_FSM_H
 #  include <netinet/tcp_fsm.h>
 # endif
 #endif
-#if HAVE_NETINET6_TCP6_H
+#ifdef HAVE_NETINET6_TCP6_H
 # include <netinet6/tcp6.h>
 #endif
-#if HAVE_NETINET6_TCP6_TIMER_H
+#ifdef HAVE_NETINET6_TCP6_TIMER_H
 #include <netinet6/tcp6_timer.h>
 #endif
-#if HAVE_NETINET6_TCP6_VAR_H
+#ifdef HAVE_NETINET6_TCP6_VAR_H
 #include <netinet6/tcp6_var.h>
 #endif
-#if HAVE_NETINET6_TCP6_FSM_H
+#ifdef HAVE_NETINET6_TCP6_FSM_H
 #include <netinet6/tcp6_fsm.h>
 #endif
-#if HAVE_INET_MIB2_H
+#ifdef HAVE_INET_MIB2_H
 #include <inet/mib2.h>
 #endif
 #ifdef HAVE_SYSLOG_H
 #include <syslog.h>
 #endif
 
-#if HAVE_KVM_GETFILES
+#ifdef HAVE_KVM_GETFILES
 #if defined(HAVE_KVM_GETFILE2) || !defined(openbsd5)
 #undef HAVE_KVM_GETFILES
 #endif
 #endif
 
-#if HAVE_KVM_GETFILES
+#ifdef HAVE_KVM_GETFILES
 #include <kvm.h>
 #include <sys/sysctl.h>
 #define _KERNEL
@@ -173,7 +176,7 @@
 
 netsnmp_feature_require(linux_read_ip6_stat);
 
-#if defined(netbsd1) && !defined(openbsd4)
+#if defined(netbsd1) && !defined(openbsd4) && __NetBSD_Version__ < 999010400
 #define inp_lport in6p_lport
 #define inp_fport in6p_fport
 #define inp_ppcb in6p_ppcb
@@ -322,8 +325,8 @@ struct variable3 ipv6_variables[] = {
 oid             ipv6_variables_oid[] = { SNMP_OID_MIB2, 55, 1 };
 #if 0
 config_load_mib(MIB .55 .1, 8, ipv6_variables)
-    config_add_mib(IPV6 - TC)
-    config_add_mib(IPV6 - MIB)
+    config_add_mib(IPV6 - TC);
+    config_add_mib(IPV6 - MIB);
 #endif
      struct variable3 ipv6icmp_variables[] = {
          {IPV6IFICMPINMSG, ASN_COUNTER, NETSNMP_OLDAPI_RONLY,
@@ -398,7 +401,7 @@ config_load_mib(MIB .55 .1, 8, ipv6_variables)
 oid             ipv6icmp_variables_oid[] = { 1, 3, 6, 1, 2, 1, 56, 1 };
 #if 0
 config_load_mib(MIB .56 .1, 8, ipv6icmp_variables)
-    config_add_mib(IPV6 - ICMP - MIB)
+    config_add_mib(IPV6 - ICMP - MIB);
 #endif
      struct variable2 ipv6udp_variables[] = {
          {IPV6UDPIFINDEX, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
@@ -407,7 +410,7 @@ config_load_mib(MIB .56 .1, 8, ipv6icmp_variables)
 oid             ipv6udp_variables_oid[] = { 1, 3, 6, 1, 2, 1, 7, 6 };
 #if 0
 config_load_mib(1.3 .6 .1 .3 .87 .1, 7, ipv6udp_variables)
-    config_add_mib(IPV6 - UDP - MIB)
+    config_add_mib(IPV6 - UDP - MIB);
 #endif
      struct variable2 ipv6tcp_variables[] = {
          {IPV6TCPCONNSTATE, ASN_INTEGER, NETSNMP_OLDAPI_RONLY,
@@ -416,7 +419,7 @@ config_load_mib(1.3 .6 .1 .3 .87 .1, 7, ipv6udp_variables)
 oid             ipv6tcp_variables_oid[] = { 1, 3, 6, 1, 2, 1, 6, 16 };
 #if 0
 config_load_mib(1.3 .6 .1 .3 .86 .1, 7, ipv6tcp_variables)
-    config_add_mib(IPV6 - TCP - MIB)
+    config_add_mib(IPV6 - TCP - MIB);
 #endif
 
 void
@@ -696,7 +699,7 @@ if_getifnet(int idx, struct ifnet *result)
 
 #endif /* !__OpenBSD__ */
 
-#if TRUST_IFLASTCHANGE         /*untrustable value returned... */
+#ifdef TRUST_IFLASTCHANGE         /*untrustable value returned... */
 #ifdef HAVE_NET_IF_MIB_H
 #if defined(HAVE_SYS_SYSCTL_H) && defined(CTL_NET)
 static int
@@ -1060,7 +1063,7 @@ var_ifv6Entry(register struct variable * vp,
 #endif
             return (u_char *) & long_return;
         }
-#if TRUST_IFLASTCHANGE         /*untrustable value returned... */
+#ifdef TRUST_IFLASTCHANGE         /*untrustable value returned... */
     case IPV6IFLASTCHANGE:
         {
             struct timeval  lastchange;
@@ -1414,7 +1417,7 @@ var_icmpv6Entry(register struct variable * vp,
 #endif
 }
 
-#if HAVE_KVM_GETFILES
+#ifdef HAVE_KVM_GETFILES
 
 u_char         *
 var_udp6(register struct variable * vp,
@@ -1624,8 +1627,13 @@ var_udp6(register struct variable * vp,
         }
 #endif
 #if defined(__NetBSD__) && __NetBSD_Version__ >= 106250000	/*1.6Y*/
+# if __NetBSD_Version__ < 999010400
         if (in6pcb.in6p_af != AF_INET6)
             goto skip;
+# else
+        if (in6pcb.in6p_pcb.inp_af != AF_INET6)
+	    goto skip;
+# endif
 #elif defined(INP_ISIPV6)
 	if (!INP_ISIPV6(&in6pcb))
 	    goto skip;
@@ -1647,6 +1655,15 @@ var_udp6(register struct variable * vp,
                 ntohs(*(uint16_t *) &in6pcb.inp_laddr6.s6_addr[2]);
         else
             newname[j++] = 0;
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+        for (i = 0; i < sizeof(struct in6_addr); i++)
+            newname[j++] = in6pcb.in6p_ip6.ip6_src.s6_addr[i];
+        newname[j++] = ntohs(in6pcb.in6p_pcb.inp_lport);
+        if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_ip6.ip6_src))
+            newname[j++] =
+                ntohs(*(uint16_t *) &in6pcb.in6p_ip6.ip6_src.s6_addr[2]);
+        else
+            newname[j++] = 0;
 #else
         for (i = 0; i < sizeof(struct in6_addr); i++)
             newname[j++] = in6pcb.in6p_laddr.s6_addr[i];
@@ -1690,6 +1707,9 @@ var_udp6(register struct variable * vp,
 #elif defined(openbsd4)
         p = (caddr_t)in6pcb.inp_queue.cqe_next;
 	if (p == first) break;
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+        p = (caddr_t)in6pcb.in6p_pcb.inp_queue.tqe_next;
+        if (p == first) break;
 #elif defined(__NetBSD__) && __NetBSD_Version__ >= 700000001
         p = (caddr_t)in6pcb.in6p_queue.tqe_next;
 	if (p == first) break;
@@ -1730,6 +1750,12 @@ var_udp6(register struct variable * vp,
                 ntohs(*(uint16_t *) & in6pcb.inp_laddr6.s6_addr[2]);
         else
             long_return = 0;
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+        if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_ip6.ip6_src))
+            long_return =
+                ntohs(*(uint16_t *) & in6pcb.in6p_ip6.ip6_src.s6_addr[2]);
+        else
+            long_return = 0;
 #else
         if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_laddr))
             long_return =
@@ -1944,7 +1970,7 @@ var_tcp6(register struct variable * vp,
     return NULL;
 }
 
-#elif HAVE_KVM_GETFILES
+#elif defined(HAVE_KVM_GETFILES)
 
 u_char         *
 var_tcp6(register struct variable * vp,
@@ -1956,7 +1982,7 @@ var_tcp6(register struct variable * vp,
     oid             savname[MAX_OID_LEN];
     int             result, count, found, savnameLen, savstate;
     int             p, i, j;
-    u_char         *lsa, *savlsa, *fsa, *savfsa;
+    u_char         *lsa, *fsa;
     struct kinfo_file *tcp;
     static int      tcp6statemap[16];
     static int      initialized = 0;
@@ -2004,8 +2030,6 @@ var_tcp6(register struct variable * vp,
         if (exact && result == 0) {
                 savnameLen = j;
                 memcpy(savname, newname, j * sizeof(oid));
-                savlsa = lsa;
-                savfsa = fsa;
                 savstate = tcp[p].t_state;
                 found++;
                 break;
@@ -2015,10 +2039,8 @@ var_tcp6(register struct variable * vp,
              */
             if (savnameLen == 0 || snmp_oid_compare(savname, savnameLen, newname, j) > 0) {
                 savnameLen = j;
-                savlsa = lsa;
-                savfsa = fsa;
-                savstate = tcp[p].t_state;
                 memcpy(savname, newname, j * sizeof(oid));
+                savstate = tcp[p].t_state;
 		found++;
             }
         }
@@ -2201,8 +2223,13 @@ var_tcp6(register struct variable * vp,
         }
 #endif
 #if defined(__NetBSD__) && __NetBSD_Version__ >= 106250000	/*1.6Y*/
+# if __NetBSD_Version__ < 999010400
         if (in6pcb.in6p_af != AF_INET6)
             goto skip;
+# else
+        if (in6pcb.in6p_pcb.inp_af != AF_INET6)
+	    goto skip;
+# endif
 #elif defined(INP_ISIPV6)
 	if (!INP_ISIPV6(&in6pcb))
 	    goto skip;
@@ -2226,6 +2253,18 @@ var_tcp6(register struct variable * vp,
                 ntohs(*(uint16_t *) &in6pcb.inp_laddr6.s6_addr[2]);
         else
             newname[j++] = 0;
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+        for (i = 0; i < sizeof(struct in6_addr); i++)
+            newname[j++] = in6pcb.in6p_ip6.ip6_src.s6_addr[i];
+        newname[j++] = ntohs(in6pcb.in6p_pcb.inp_lport);
+        for (i = 0; i < sizeof(struct in6_addr); i++)
+            newname[j++] = in6pcb.in6p_ip6.ip6_dst.s6_addr[i];
+        newname[j++] = ntohs(in6pcb.in6p_pcb.inp_fport);
+        if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_ip6.ip6_src))
+            newname[j++] =
+                ntohs(*(uint16_t *) &in6pcb.in6p_ip6.ip6_src.s6_addr[2]);
+        else
+            newname[j++] = 0;
 #else
         for (i = 0; i < sizeof(struct in6_addr); i++)
             newname[j++] = in6pcb.in6p_laddr.s6_addr[i];
@@ -2246,7 +2285,11 @@ var_tcp6(register struct variable * vp,
         DEBUGMSG(("mibII/ipv6", " %d\n", exact));
 
 #if 1                           /* this is very odd but sometimes happen, and cause infinite loop */
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+        if (ntohs(in6pcb.in6p_pcb.inp_lport) == 0)
+#else
         if (ntohs(in6pcb.inp_lport) == 0)
+#endif
             goto skip;
 #endif
         result = snmp_oid_compare(name, *length, newname, j);
@@ -2276,6 +2319,9 @@ var_tcp6(register struct variable * vp,
 #elif defined(openbsd4)
         p = (caddr_t)in6pcb.inp_queue.cqe_next;
 	if (p == first) break;
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+        p = (caddr_t)in6pcb.in6p_pcb.inp_queue.tqe_next;
+        if (p == first) break;
 #elif defined(__NetBSD__) && __NetBSD_Version__ >= 700000001
         p = (caddr_t)in6pcb.in6p_queue.tqe_next;
 	if (p == first) break;
@@ -2299,9 +2345,15 @@ var_tcp6(register struct variable * vp,
     *length = savnameLen;
     memcpy((char *) name, (char *) savname, *length * sizeof(oid));
     memcpy(&in6pcb, &savpcb, sizeof(savpcb));
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+    if (!NETSNMP_KLOOKUP(in6pcb.in6p_pcb.inp_ppcb, (char *) &tcpcb, sizeof(tcpcb))) {
+        DEBUGMSGTL(("mibII/ipv6", "klookup fail for tcb6.tcpcb at %p\n",
+                    in6pcb.in6p_pcb.inp_ppcb));
+#else
     if (!NETSNMP_KLOOKUP(in6pcb.inp_ppcb, (char *) &tcpcb, sizeof(tcpcb))) {
 	DEBUGMSGTL(("mibII/ipv6", "klookup fail for tcb6.tcpcb at %p\n",
 		    in6pcb.inp_ppcb));
+#endif
 	found = 0;
 	return NULL;
     }
