@@ -6,7 +6,7 @@
 #define _MIBGROUP_ROUTE_WRITE_H
 
 #if !defined(NETSNMP_ENABLE_MFD_REWRITES)
-config_require(mibII/ip)
+config_require(mibII/ip);
 #endif
 
      int             addRoute(u_long, u_long, u_long, u_short);
