@@ -108,6 +108,10 @@ struct netsnmp_inpcb_s {
 #define	UDPTABLE_ENTRY_TYPE	netsnmp_inpcb 
 #define	UDPTABLE_LOCALADDRESS	pcb.inp_laddr.s_addr 
 #define	UDPTABLE_LOCALPORT	pcb.inp_lport
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+#define	UDPTABLE_ENTRY_TYPE	struct in4pcb 
+#define	UDPTABLE_LOCALADDRESS	in4p_ip.ip_src.s_addr
+#define	UDPTABLE_LOCALPORT	in4p_pcb.inp_lport
 #else
 #define	UDPTABLE_ENTRY_TYPE	struct inpcb 
 #define	UDPTABLE_LOCALADDRESS	inp_laddr.s_addr 
@@ -430,7 +434,13 @@ udpTable_next_entry( void **loop_context,
      * and update the loop context ready for the next one.
      */
     *data_context = (void*)entry;
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+    *loop_context = (void*)TAILQ_NEXT(entry, in4p_pcb.inp_queue);
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 699002800
+    *loop_context = (void*)TAILQ_NEXT(entry, inp_queue);
+#else
     *loop_context = (void*)entry->INP_NEXT_SYMBOL;
+#endif
     return index;
 }
 
@@ -440,7 +450,13 @@ udpTable_free(netsnmp_cache *cache, void *magic)
     UDPTABLE_ENTRY_TYPE	 *p;
     while (udp_head) {
         p = udp_head;
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 999010400
+        udp_head = TAILQ_NEXT(udp_head, in4p_pcb.inp_queue);
+#elif defined(__NetBSD__) && __NetBSD_Version__ >= 699002800
+        udp_head = TAILQ_NEXT(udp_head, inp_queue);
+#else
         udp_head = udp_head->INP_NEXT_SYMBOL;
+#endif
         free(p);
     }
 
@@ -752,7 +768,11 @@ udpTable_load(netsnmp_cache *cache, void *vmagic)
     /*
      *  Set up a linked list
      */
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 699002800
+    entry  = TAILQ_FIRST(&table.inpt_queue);
+#else
     entry  = table.INP_FIRST_SYMBOL;
+#endif
     while (entry) {
    
         nnew = SNMP_MALLOC_TYPEDEF(struct inpcb);
@@ -768,7 +788,11 @@ udpTable_load(netsnmp_cache *cache, void *vmagic)
 	nnew->INP_NEXT_SYMBOL = udp_head;
 	udp_head = nnew;
 
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 699002800
+        if (entry == TAILQ_FIRST(&table.inpt_queue))
+#else
         if (entry == table.INP_FIRST_SYMBOL)
+#endif
             break;
     }
 
@@ -809,11 +833,20 @@ udpTable_load(netsnmp_cache *cache, void *vmagic)
             break;
         }
 
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 699002800
+        entry    = TAILQ_NEXT(nnew, inp_queue);        /* Next kernel entry */
+       TAILQ_NEXT(nnew, inp_queue) = udp_head;
+#else
         entry    = nnew->INP_NEXT_SYMBOL;		/* Next kernel entry */
 	nnew->INP_NEXT_SYMBOL = udp_head;
+#endif
 	udp_head = nnew;
 
+#if defined(__NetBSD__) && __NetBSD_Version__ >= 699002800
+        if (entry == TAILQ_FIRST(&table.inpt_queue))
+#else
         if (entry == udp_inpcb.INP_NEXT_SYMBOL)
+#endif
             break;
     }
 
