@@ -5,8 +5,10 @@
 #ifndef _MIBGROUP_UDPTABLE_H
 #define _MIBGROUP_UDPTABLE_H
 
-config_arch_require(solaris2, kernel_sunos5)
-config_require(mibII/ip)
+#ifdef solaris2
+config_require(kernel_sunos5);
+#endif
+config_require(mibII/ip);
 
 extern void     init_udpTable(void);
 extern Netsnmp_Node_Handler udpTable_handler;
