@@ -11,7 +11,7 @@
 
 #include <net-snmp/net-snmp-config.h>
 
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
