@@ -1,10 +1,11 @@
 #include <net-snmp/net-snmp-config.h>
+#include <net-snmp/net-snmp-features.h>
 
 #include <sys/types.h>
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
-#if HAVE_NETDB_H
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
 
@@ -16,8 +17,15 @@
 #include <net-snmp/agent/table.h>
 #include <net-snmp/agent/table_data.h>
 #include <net-snmp/agent/table_dataset.h>
+#include "net-snmp/agent/sysORTable.h"
 #include "notification_log.h"
 
+netsnmp_feature_require(register_ulong_instance_context);
+netsnmp_feature_require(register_read_only_counter32_instance_context);
+netsnmp_feature_require(delete_table_data_set);
+netsnmp_feature_require(table_dataset);
+netsnmp_feature_require(date_n_time);
+
 /*
  * column number definitions for table nlmLogTable
  */
@@ -57,6 +65,8 @@ static u_long   max_age = 1440; /* 1440 = 24 hours, which is the mib default */
 static netsnmp_table_data_set *nlmLogTable;
 static netsnmp_table_data_set *nlmLogVarTable;
 
+static oid nlm_module_oid[] = { SNMP_OID_MIB2, 92 }; /* NOTIFICATION-LOG-MIB::notificationLogMIB */
+
 static void
 netsnmp_notif_log_remove_oldest(int count)
 {
@@ -126,11 +136,9 @@ check_log_size(unsigned int clientreg, void *clientarg)
     netsnmp_table_row *row;
     netsnmp_table_data_set_storage *data;
     u_long          count = 0;
-    struct timeval  now;
     u_long          uptime;
 
-    gettimeofday(&now, NULL);
-    uptime = netsnmp_timeval_uptime(&now);
+    uptime = netsnmp_get_agent_uptime();
 
     if (!nlmLogTable || !nlmLogTable->table )  {
         DEBUGMSGTL(("notification_log", "missing log table\n"));
@@ -466,8 +474,10 @@ notification_log_config_handler(netsnmp_mib_handler *handler,
      * configuration variables get set to a value and thus
      * notifications must be possibly deleted from our archives.
      */
+#ifndef NETSNMP_NO_WRITE_SUPPORT
     if (reqinfo->mode == MODE_SET_COMMIT)
         check_log_size(0, NULL);
+#endif /* !NETSNMP_NO_WRITE_SUPPORT */
     return SNMP_ERR_NOERROR;
 }
 
@@ -548,6 +558,9 @@ init_notification_log(void)
                                NETSNMP_DS_APPLICATION_ID,
                                NETSNMP_DS_AGENT_NOTIF_LOG_MAX);
 #endif
+
+    REGISTER_SYSOR_ENTRY(nlm_module_oid, 
+        "The MIB module for logging SNMP Notifications.");
 }
 
 void
@@ -555,13 +568,16 @@ shutdown_notification_log(void)
 {
     max_logged = 0;
     check_log_size(0, NULL);
+    netsnmp_delete_table_data_set(nlmLogTable);
+    nlmLogTable = NULL;
+
+    UNREGISTER_SYSOR_ENTRY(nlm_module_oid);
 }
 
 void
 log_notification(netsnmp_pdu *pdu, netsnmp_transport *transport)
 {
     long            tmpl;
-    struct timeval  now;
     netsnmp_table_row *row;
 
     static u_long   default_num = 0;
@@ -601,8 +617,7 @@ log_notification(netsnmp_pdu *pdu, netsnmp_transport *transport)
     /*
      * add the data 
      */
-    gettimeofday(&now, NULL);
-    tmpl = netsnmp_timeval_uptime(&now);
+    tmpl = netsnmp_get_agent_uptime();
     netsnmp_set_row_column(row, COLUMN_NLMLOGTIME, ASN_TIMETICKS,
                            &tmpl, sizeof(tmpl));
     time(&timetnow);
