@@ -15,7 +15,7 @@
 #include <net-snmp/net-snmp-features.h>
 #include <stdlib.h>
 
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
