@@ -2,7 +2,7 @@
 
 #include <net-snmp/net-snmp-features.h>
 
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
