@@ -1,6 +1,6 @@
 #ifndef SNMPTLSTMSESSION_H
 #define SNMPTLSTMSESSION_H
 
-config_require(tlstm-mib/snmpTlstmSession/snmpTlstmSession)
+config_require(tlstm-mib/snmpTlstmSession/snmpTlstmSession);
 
 #endif /* SNMPTLSTMSESSION_H */
