@@ -14,11 +14,11 @@
 /*
  * needed by util_funcs.h 
  */
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
@@ -27,12 +27,23 @@
 
 #include <math.h>
 
+#if defined (linux)
+/* for stat() */
+#include <ctype.h>
+#include <sys/stat.h>
+#endif
+
+#ifdef HAVE_SYS_SYSMACROS_H
+#include <sys/sysmacros.h> /* major() */
+#endif
+
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 #include <net-snmp/agent/agent_callbacks.h>
 
 #include "util_funcs/header_simple_table.h"
 
+#include "struct.h"
 /*
  * include our .h file 
  */
@@ -77,9 +88,9 @@ static int ps_numdisks;			/* number of disks in system, may change while running
 
 #if defined(HAVE_GETDEVS) || defined(HAVE_DEVSTAT_GETDEVS)
 #include <sys/param.h>
-#if HAVE_DEVSTAT_GETDEVS
+#ifdef HAVE_DEVSTAT_GETDEVS
 #include <sys/resource.h>       /* for CPUSTATES in devstat.h */
-#elif HAVE_SYS_DKSTAT_H
+#elif defined(HAVE_SYS_DKSTAT_H)
 #include <sys/dkstat.h>
 #endif
 #include <devstat.h>
@@ -91,7 +102,7 @@ static int ps_numdisks;			/* number of disks in system, may change while running
 
 #endif                          /* freebsd */
 
-#if HAVE_DEVSTAT_GETDEVS
+#ifdef HAVE_DEVSTAT_GETDEVS
   #define GETDEVS(x) devstat_getdevs(NULL, (x))
 #else
   #define GETDEVS(x) getdevs((x))
@@ -100,6 +111,54 @@ static int ps_numdisks;			/* number of disks in system, may change while running
 #if defined (linux)
 #define DISKIO_SAMPLE_INTERVAL 5
 void devla_getstats(unsigned int regno, void * dummy);
+static void diskio_parse_config_disks(const char *token, char *cptr);
+static int diskio_pre_update_config(int, int, void *, void *);
+static void diskio_free_config(void);
+
+#define DISK_INCR 2
+
+typedef struct linux_diskio
+{
+    int major;
+    int  minor;
+    unsigned long  blocks;
+    char name[256];
+    unsigned long  rio;
+    unsigned long  rmerge;
+    unsigned long  rsect;
+    unsigned long  ruse;
+    unsigned long  wio;
+    unsigned long  wmerge;
+    unsigned long  wsect;
+    unsigned long  wuse;
+    unsigned long  running;
+    unsigned long  use;
+    unsigned long  aveq;
+} linux_diskio;
+
+/* disk load averages */
+typedef struct linux_diskio_la
+{
+    unsigned long use_prev;
+    double la1, la5, la15;
+} linux_diskio_la;
+
+typedef struct linux_diskio_header
+{
+    linux_diskio* indices;
+    int length;
+    int alloc;
+} linux_diskio_header;
+
+typedef struct linux_diskio_la_header
+{
+    linux_diskio_la * indices;
+    int length;
+} linux_diskio_la_header;
+
+static linux_diskio_header head;
+static linux_diskio_la_header la_head;
+
 #endif /* linux */
 
 #if defined (darwin)
@@ -120,10 +179,18 @@ static int      getstats(void);
 void		devla_getstats(unsigned int regno, void *dummy);
 #endif
 
-FILE           *file;
-
 #ifdef linux
-static int	diskio_free_config(int, int, void *, void *);
+struct diskiopart {
+    char            syspath[STRMAX];	/* full stat path */
+    char            name[STRMAX];	/* name as provided */
+    char            shortname[STRMAX];	/* short name for output */
+    int             major;
+    int             minor;
+};
+
+static int             numdisks;
+static int             maxdisks = 0;
+static struct diskiopart *disks;
 #endif
 
          /*********************
@@ -184,6 +251,8 @@ init_diskio(void)
          var_diskio, 1, {12}},
         {DISKIO_NWRITTENX, ASN_COUNTER64, NETSNMP_OLDAPI_RONLY,
          var_diskio, 1, {13}},
+        {DISKIO_BUSYTIME, ASN_COUNTER64, NETSNMP_OLDAPI_RONLY,
+         var_diskio, 1, {14}},
     };
 
     /*
@@ -249,11 +318,13 @@ init_diskio(void)
                                NETSNMP_DS_APPLICATION_ID,
                                NETSNMP_DS_AGENT_DISKIO_NO_RAM);
 
-        /* or possible an exclusion pattern? */
+    snmpd_register_config_handler("diskio", diskio_parse_config_disks,
+        diskio_free_config, "path | device");
+    
 
     snmp_register_callback(SNMP_CALLBACK_APPLICATION,
 	                   SNMPD_CALLBACK_PRE_UPDATE_CONFIG,
-	                   diskio_free_config, NULL);
+	                   diskio_pre_update_config, NULL);
 
 #endif
 }
@@ -261,8 +332,17 @@ init_diskio(void)
 #ifdef linux
 /* to do: make sure diskio_free_config() gets invoked upon SIGHUP. */
 static int
-diskio_free_config(int major, int minor, void *serverarg, void *clientarg)
+diskio_pre_update_config(int major, int minor, void *serverarg, void *clientarg)
 {
+    diskio_free_config();
+    return 0;
+}
+
+static void
+diskio_free_config(void)
+{
+    int i;
+
     DEBUGMSGTL(("diskio", "free config %d\n",
 		netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID,
 				       NETSNMP_DS_AGENT_DISKIO_NO_RAM)));
@@ -272,9 +352,138 @@ diskio_free_config(int major, int minor, void *serverarg, void *clientarg)
 			   NETSNMP_DS_AGENT_DISKIO_NO_LOOP, 0);
     netsnmp_ds_set_boolean(NETSNMP_DS_APPLICATION_ID, 
 			   NETSNMP_DS_AGENT_DISKIO_NO_RAM,  0);
-    return 0;
+
+    if (la_head.length) {
+        /* reset any usage stats, we may get different list of devices from config */
+        free(la_head.indices);
+        la_head.length = 0;
+        la_head.indices = NULL;
+    }
+    if (numdisks > 0) {
+        head.length = 0;
+        numdisks = 0;
+        for (i = 0; i < maxdisks; i++) {    /* init/erase disk db */
+            disks[i].syspath[0] = 0;
+            disks[i].name[0] = 0;
+            disks[i].shortname[0] = 0;
+            disks[i].major = -1;
+            disks[i].minor = -1;
+        }
+    }
 }
-#endif
+
+static int
+disk_exists(char *path) 
+{
+    int index;
+    for(index = 0; index < numdisks; index++) {
+        DEBUGMSGTL(("ucd-snmp/disk", "Checking for %s. Found %s at %d\n", path, disks[index].syspath, index));
+        if(strcmp(path, disks[index].syspath) == 0) {
+            return index;
+        }
+    }
+    return -1;
+}
+
+static void
+add_device(char *path, int addNewDisks ) 
+{
+    int index;
+    char device[STRMAX];
+    char syspath[STRMAX];
+    char *basename;
+    struct stat stbuf;
+
+    if (!path || !strcmp(path, "none")) {
+        DEBUGMSGTL(("ucd-snmp/diskio", "Skipping null path device (%s)\n", path));
+        return;
+    }
+    if (numdisks == maxdisks) {
+        if (maxdisks == 0) {
+            maxdisks = 50;
+            disks = malloc(maxdisks * sizeof(struct diskiopart));
+            if (!disks) {
+                config_perror("malloc failed for new disko allocation.");
+	            netsnmp_config_error("\tignoring:  %s", path);
+                return;
+            }
+            memset(disks, 0, maxdisks * sizeof(struct diskiopart));
+        } else {
+            struct diskiopart *newdisks;
+            maxdisks *= 2;
+            newdisks = realloc(disks, maxdisks * sizeof(struct diskiopart));
+            if (!newdisks) {
+                free(disks);
+                disks = NULL;
+                config_perror("malloc failed for new disko allocation.");
+	            netsnmp_config_error("\tignoring:  %s", path);
+                return;
+            }
+            disks = newdisks;
+            memset(disks + maxdisks/2, 0, maxdisks/2 * sizeof(struct diskiopart));
+        }
+    }
+
+    /* first find the path for this device */
+    device[0]='\0';
+    if ( *path != '/' ) {
+        strlcpy(device, "/dev/", STRMAX - 1 );
+    }
+    strncat(device, path, STRMAX - 1 );
+
+    /* check for /dev existence */
+    if ( stat(device,&stbuf)!=0 ) { /* ENOENT */
+        config_perror("diskio path does not exist.");
+        netsnmp_config_error("\tignoring:  %s", path);
+        return;
+    }
+    else if ( ! S_ISBLK(stbuf.st_mode) ) { /* ENODEV */
+        config_perror("diskio path is not a device.");
+        netsnmp_config_error("\tignoring:  %s", path);
+        return;
+    }
+
+    /* either came with a slash or we just put one there, so the following always works */
+    basename = strrchr(device, '/' )+1;
+    /* construct a sys path using the device numbers to avoid having to disambiguate the various text forms */
+    snprintf( syspath, STRMAX - 1, "/sys/dev/block/%d:%d/stat", major(stbuf.st_rdev), minor(stbuf.st_rdev) );
+    DEBUGMSGTL(("ucd-snmp/diskio", " monitoring sys path (%s)\n", syspath));
+
+    index = disk_exists(syspath);
+
+    if(index == -1 && addNewDisks){
+        /* The following buffers are cleared above, no need to add '\0' */
+        strlcpy(disks[numdisks].syspath, syspath, sizeof(disks[numdisks].syspath) - 1);
+        strlcpy(disks[numdisks].name, path, sizeof(disks[numdisks].name) - 1);
+        strlcpy(disks[numdisks].shortname, basename, sizeof(disks[numdisks].shortname) - 1);
+        disks[numdisks].major = major(stbuf.st_rdev);
+        disks[numdisks].minor = minor(stbuf.st_rdev);
+        numdisks++;  
+    }
+}
+
+static void 
+diskio_parse_config_disks(const char *token, char *cptr)
+{
+#if defined(HAVE_FSTAB_H) || defined(HAVE_GETMNTENT) || defined(HAVE_STATFS)
+    char path[STRMAX];
+
+
+    /*
+     * read disk path (eg, /1 or /usr) 
+     */
+    copy_nword(cptr, path, sizeof(path));
+
+    /* TODO: we may include regular expressions in future */
+    /*
+     * check if the disk already exists, if so then modify its
+     * parameters. if it does not exist then add it
+     */
+    add_device(path, 1);
+#endif /* HAVE_FSTAB_H || HAVE_GETMNTENT || HAVE_STATFS */
+}
+
+#endif /* linux */
 
 
 #ifdef solaris2
@@ -354,12 +563,12 @@ var_diskio(struct variable * vp,
         return (u_char *) & long_ret;
     case DISKIO_NREADX:
         *var_len = sizeof(struct counter64);
-        c64_ret.low = kio.nread & 0xffffffff;;
+        c64_ret.low = kio.nread & 0xffffffff;
         c64_ret.high = kio.nread >> 32;
         return (u_char *) & c64_ret;
     case DISKIO_NWRITTENX:
         *var_len = sizeof(struct counter64);
-        c64_ret.low = kio.nwritten & 0xffffffff;;
+        c64_ret.low = kio.nwritten & 0xffffffff;
         c64_ret.high = kio.nwritten >> 32;
         return (u_char *) & c64_ret;
     case DISKIO_READS:
@@ -566,6 +775,7 @@ var_diskio(struct variable * vp,
            int exact, size_t * var_len, WriteMethod ** write_method)
 {
     static long     long_ret;
+    static long long        longlong_ret;
     static struct counter64 c64_ret;
     unsigned int    indx;
 
@@ -609,7 +819,12 @@ var_diskio(struct variable * vp,
         c64_ret.low = dk[indx].ds_rbytes & 0xffffffff;
         c64_ret.high = dk[indx].ds_rbytes >> 32;
         return (u_char *) & c64_ret;
-
+    case DISKIO_BUSYTIME:
+        *var_len = sizeof(struct counter64);
+	longlong_ret = dk[indx].ds_time.tv_sec*1000000 + dk[indx].ds_time.tv_usec;
+        c64_ret.low = longlong_ret & 0xffffffff;
+        c64_ret.high = longlong_ret >> 32;
+	return (u_char *) &c64_ret;
     default:
         ERROR_MSG("diskio.c: don't know how to handle this request.");
     }
@@ -699,6 +914,8 @@ var_diskio(struct variable * vp,
            int exact, size_t * var_len, WriteMethod ** write_method)
 {
     static long     long_ret;
+    static long long        longlong_ret;
+    static struct counter64 c64_ret;
     unsigned int    indx;
 
     if (getstats() == 0)
@@ -741,6 +958,20 @@ var_diskio(struct variable * vp,
 #endif
         return (u_char *) & long_ret;
 
+    case DISKIO_NREADX:
+        *var_len = sizeof(struct counter64);
+        longlong_ret = dk[indx].rbytes;
+        c64_ret.low = longlong_ret & 0xffffffff;
+        c64_ret.high = longlong_ret >> 32;
+        return (u_char *) & c64_ret;
+
+    case DISKIO_NWRITTENX:
+        *var_len = sizeof(struct counter64);
+        longlong_ret = dk[indx].wbytes;
+        c64_ret.low = longlong_ret & 0xffffffff;
+        c64_ret.high = longlong_ret >> 32;
+        return (u_char *) & c64_ret;
+
     case DISKIO_READS:
 #ifdef HW_DISKSTATS
      	long_ret = dk[indx].dk_rxfer;
@@ -761,6 +992,21 @@ var_diskio(struct variable * vp,
 #endif
         return (u_char *) & long_ret;
 
+    case DISKIO_BUSYTIME:
+#ifdef HW_IOSTATS
+        *var_len = sizeof(struct counter64);
+	if (dk[indx].type == IOSTAT_DISK) {
+	    longlong_ret = dk[indx].time_sec*1000 + dk[indx].time_usec/1000;
+	    c64_ret.low = longlong_ret & 0xffffffff;
+	    c64_ret.high = longlong_ret >> 32;
+	    return (u_char *) & c64_ret;
+	}
+	else
+	    return NULL;
+#else
+	return NULL;
+#endif
+
     default:
         ERROR_MSG("diskio.c: don't know how to handle this request.");
     }
@@ -773,7 +1019,7 @@ var_diskio(struct variable * vp,
 /* disk load average patch by Rojer */
 
 struct dev_la {
-#if HAVE_DEVSTAT_GETDEVS
+#ifdef HAVE_DEVSTAT_GETDEVS
         struct bintime prev;
 #else
         struct timeval prev;
@@ -785,7 +1031,7 @@ struct dev_la {
 static struct dev_la *devloads = NULL;
 static int ndevs = 0;
 
-#if ! HAVE_DEVSTAT_GETDEVS
+#ifndef HAVE_DEVSTAT_GETDEVS
 double devla_timeval_diff(struct timeval *t1, struct timeval *t2) {
 
         double dt1 = (double) t1->tv_sec + (double) t1->tv_usec * 0.000001;
@@ -847,7 +1093,7 @@ void devla_getstats(unsigned int regno, void *dummy) {
                 }
 
         for (i=0; i<ndevs; i++) {
-#if HAVE_DEVSTAT_GETDEVS
+#ifdef HAVE_DEVSTAT_GETDEVS
                 busy_time = devstat_compute_etime(&lastat->dinfo->devices[i].busy_time, &devloads[i].prev);
 #else
                 busy_time = devla_timeval_diff(&devloads[i].prev, &lastat->dinfo->devices[i].busy_time);
@@ -937,28 +1183,28 @@ var_diskio(struct variable * vp,
 
     switch (vp->magic) {
     case DISKIO_INDEX:
-        long_ret = (long) indx + 1;;
+        long_ret = (long) indx + 1;
         return (u_char *) & long_ret;
     case DISKIO_DEVICE:
         *var_len = strlen(stat->dinfo->devices[indx].device_name);
         return (u_char *) stat->dinfo->devices[indx].device_name;
     case DISKIO_NREAD:
-#if HAVE_DEVSTAT_GETDEVS
-        long_ret = (signed long) stat->dinfo->devices[indx].bytes[DEVSTAT_READ];
+#ifdef HAVE_DEVSTAT_GETDEVS
+        long_ret = (signed long) stat->dinfo->devices[indx].bytes[DEVSTAT_READ] & 0xFFFFFFFF;
 #else
         long_ret = (signed long) stat->dinfo->devices[indx].bytes_read;
 #endif
         return (u_char *) & long_ret;
     case DISKIO_NWRITTEN:
-#if HAVE_DEVSTAT_GETDEVS
-        long_ret = (signed long) stat->dinfo->devices[indx].bytes[DEVSTAT_WRITE];
+#ifdef HAVE_DEVSTAT_GETDEVS
+        long_ret = (signed long) stat->dinfo->devices[indx].bytes[DEVSTAT_WRITE] & 0xFFFFFFFF;
 #else
         long_ret = (signed long) stat->dinfo->devices[indx].bytes_written;
 #endif
         return (u_char *) & long_ret;
     case DISKIO_NREADX:
         *var_len = sizeof(struct counter64);
-#if HAVE_DEVSTAT_GETDEVS
+#ifdef HAVE_DEVSTAT_GETDEVS
         longlong_ret = stat->dinfo->devices[indx].bytes[DEVSTAT_READ];
 #else
         longlong_ret = stat->dinfo->devices[indx].bytes_read;
@@ -968,7 +1214,7 @@ var_diskio(struct variable * vp,
         return (u_char *) & c64_ret;
     case DISKIO_NWRITTENX:
         *var_len = sizeof(struct counter64);
-#if HAVE_DEVSTAT_GETDEVS
+#ifdef HAVE_DEVSTAT_GETDEVS
         longlong_ret = stat->dinfo->devices[indx].bytes[DEVSTAT_WRITE];
 #else
         longlong_ret = stat->dinfo->devices[indx].bytes_written;
@@ -977,15 +1223,15 @@ var_diskio(struct variable * vp,
         c64_ret.high = longlong_ret >> 32;
         return (u_char *) & c64_ret;
     case DISKIO_READS:
-#if HAVE_DEVSTAT_GETDEVS
-        long_ret = (signed long) stat->dinfo->devices[indx].operations[DEVSTAT_READ];
+#ifdef HAVE_DEVSTAT_GETDEVS
+        long_ret = (signed long) stat->dinfo->devices[indx].operations[DEVSTAT_READ] & 0xFFFFFFFF;
 #else
         long_ret = (signed long) stat->dinfo->devices[indx].num_reads;
 #endif
         return (u_char *) & long_ret;
     case DISKIO_WRITES:
-#if HAVE_DEVSTAT_GETDEVS
-        long_ret = (signed long) stat->dinfo->devices[indx].operations[DEVSTAT_WRITE];
+#ifdef HAVE_DEVSTAT_GETDEVS
+        long_ret = (signed long) stat->dinfo->devices[indx].operations[DEVSTAT_WRITE] & 0xFFFFFFFF;
 #else
         long_ret = (signed long) stat->dinfo->devices[indx].num_writes;
 #endif
@@ -1010,49 +1256,6 @@ var_diskio(struct variable * vp,
 
 #ifdef linux
 
-#define DISK_INCR 2
-
-typedef struct linux_diskio
-{
-    int major;
-    int  minor;
-    unsigned long  blocks;
-    char name[256];
-    unsigned long  rio;
-    unsigned long  rmerge;
-    unsigned long  rsect;
-    unsigned long  ruse;
-    unsigned long  wio;
-    unsigned long  wmerge;
-    unsigned long  wsect;
-    unsigned long  wuse;
-    unsigned long  running;
-    unsigned long  use;
-    unsigned long  aveq;
-} linux_diskio;
-
-/* disk load averages */
-typedef struct linux_diskio_la
-{
-    unsigned long use_prev;
-    double la1, la5, la15;
-} linux_diskio_la;
-
-typedef struct linux_diskio_header
-{
-    linux_diskio* indices;
-    int length;
-    int alloc;
-} linux_diskio_header;
-
-typedef struct linux_diskio_la_header
-{
-    linux_diskio_la * indices;   
-    int length;
-} linux_diskio_la_header;
-
-static linux_diskio_header head;
-static linux_diskio_la_header la_head;
 
 void devla_getstats(unsigned int regno, void * dummy) {
 
@@ -1116,9 +1319,52 @@ int is_excluded(const char *name)
     return 0;
 }
 
+static int get_sysfs_stats(void)
+{
+    int i;
+    char buffer[1024];
+
+    head.length  = 0;
+
+    for(i = 0; i < numdisks; i++) {
+        FILE *f = fopen(disks[i].syspath, "r");
+        if ( f == NULL ) {
+            DEBUGMSGTL(("ucd-snmp/diskio", "Can't open %s, skipping", disks[i].syspath));
+            continue;
+        }
+
+        if (fgets(buffer, sizeof(buffer), f) == NULL) {
+            DEBUGMSGTL(("ucd-snmp/diskio", "Can't read %s, skipping", disks[i].syspath));
+            fclose(f);
+            continue;
+        }
+
+        linux_diskio* pTemp;
+        if (head.length == head.alloc) {
+            head.alloc += DISK_INCR;
+            head.indices = (linux_diskio *) realloc(head.indices, head.alloc*sizeof(linux_diskio));
+        }
+        pTemp = &head.indices[head.length];
+        pTemp->major = disks[i].major;
+        pTemp->minor = disks[i].minor;
+        strlcpy( pTemp->name, disks[i].shortname, sizeof(pTemp->name) - 1 );
+        if (sscanf (buffer, "%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu\n",
+                &pTemp->rio, &pTemp->rmerge, &pTemp->rsect, &pTemp->ruse,
+                &pTemp->wio, &pTemp->wmerge, &pTemp->wsect, &pTemp->wuse,
+                &pTemp->running, &pTemp->use, &pTemp->aveq) != 11)
+            sscanf (buffer, "%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu%*[ \n\t]%lu\n",
+                &pTemp->rio, &pTemp->rsect,
+                &pTemp->wio, &pTemp->wsect);
+        head.length++;
+        fclose(f);
+    }
+    return 0;
+}
+
 static int
 getstats(void)
 {
+    struct stat stbuf;
     FILE* parts;
     time_t now;
     
@@ -1135,6 +1381,13 @@ getstats(void)
 
     memset(head.indices, 0, head.alloc*sizeof(linux_diskio));
 
+    if (numdisks>0) {
+        /* 'diskio' configuration is used - go through the whitelist only and
+         * read /sys/dev/block/xxx */
+        cache_time = now;
+        return get_sysfs_stats();
+    }
+    /* 'diskio' configuration is not used - report all devices */
     /* Is this a 2.6 kernel? */
     parts = fopen("/proc/diskstats", "r");
     if (parts) {
@@ -1160,6 +1413,10 @@ getstats(void)
 	        head.length++;
 	}
     }
+    else if (stat("/proc/vz", &stbuf) == 0) {
+        /* OpenVZ / Virtuozzo containers do not have /proc/diskstats */
+        goto update_cache_time;
+    }
     else {
 	/* See if a 2.4 kernel */
 	char buffer[1024];
@@ -1173,8 +1430,8 @@ getstats(void)
 	/*
 	 * first few fscanfs are garbage we don't care about. skip it.
 	 */
-	fgets(buffer, sizeof(buffer), parts);
-	fgets(buffer, sizeof(buffer), parts);
+	NETSNMP_IGNORE_RESULT(fgets(buffer, sizeof(buffer), parts));
+	NETSNMP_IGNORE_RESULT(fgets(buffer, sizeof(buffer), parts));
 
 	while (! feof(parts)) {
 	    linux_diskio* pTemp;
@@ -1185,7 +1442,7 @@ getstats(void)
 	    }
 	    pTemp = &head.indices[head.length];
 
-	    rc = fscanf (parts, "%d %d %lu %s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
+	    rc = fscanf(parts, "%d %d %lu %255s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
 		    &pTemp->major, &pTemp->minor, &pTemp->blocks, pTemp->name,
 		    &pTemp->rio, &pTemp->rmerge, &pTemp->rsect, &pTemp->ruse,
 		    &pTemp->wio, &pTemp->wmerge, &pTemp->wsect, &pTemp->wuse,
@@ -1201,6 +1458,8 @@ getstats(void)
     }
 
     fclose(parts);
+
+update_cache_time:
     cache_time = now;
     return 0;
 }
@@ -1251,14 +1510,28 @@ var_diskio(struct variable * vp,
       long_ret = head.indices[indx].wio & 0xffffffff;
       return (u_char *) & long_ret;
     case DISKIO_LA1:
-      long_ret = la_head.indices[indx].la1;
+      if (la_head.length > indx)
+          long_ret = la_head.indices[indx].la1;
+      else
+          long_ret = 0; /* we don't have the load yet */
       return (u_char *) & long_ret;
     case DISKIO_LA5:
-      long_ret = la_head.indices[indx].la5;
+      if (la_head.length > indx)
+          long_ret = la_head.indices[indx].la5;
+      else
+          long_ret = 0; /* we don't have the load yet */
       return (u_char *) & long_ret;
     case DISKIO_LA15:
-      long_ret = la_head.indices[indx].la15;
+      if (la_head.length > indx)
+          long_ret = la_head.indices[indx].la15;
+      else
+          long_ret = 0;
       return (u_char *) & long_ret;
+    case DISKIO_BUSYTIME:
+      *var_len = sizeof(struct counter64);
+      c64_ret.low = head.indices[indx].use*1000 & 0xffffffff;
+      c64_ret.high = head.indices[indx].use*1000 >> 32;
+      return (u_char *) & c64_ret;
     case DISKIO_NREADX:
       *var_len = sizeof(struct counter64);
       c64_ret.low = head.indices[indx].rsect * 512 & 0xffffffff;
@@ -1617,12 +1890,12 @@ var_diskio(struct variable * vp,
         return (u_char *) & long_ret;
     case DISKIO_NREADX:
         *var_len = sizeof(struct counter64);
-        c64_ret.low = (ps_disk[indx].rblks * ps_disk[indx].bsize) & 0xffffffff;;
+        c64_ret.low = (ps_disk[indx].rblks * ps_disk[indx].bsize) & 0xffffffff;
         c64_ret.high = (ps_disk[indx].rblks * ps_disk[indx].bsize) >> 32;
         return (u_char *) & c64_ret;
     case DISKIO_NWRITTENX:
         *var_len = sizeof(struct counter64);
-        c64_ret.low = (ps_disk[indx].wblks * ps_disk[indx].bsize) & 0xffffffff;;
+        c64_ret.low = (ps_disk[indx].wblks * ps_disk[indx].bsize) & 0xffffffff;
         c64_ret.high = (ps_disk[indx].wblks * ps_disk[indx].bsize) >> 32;
         return (u_char *) & c64_ret;
 
