@@ -6,11 +6,11 @@
 #ifndef MIBGROUP_DLMOD_H
 #define MIBGROUP_DLMOD_H
 
-#if !defined(HAVE_DLFCN_H) || !defined(HAVE_DLOPEN)
-config_error(Dynamic modules not supported on this platform)
+#if (!defined(HAVE_DLFCN_H) || !defined(HAVE_DLOPEN)) && !defined(WIN32)
+config_error(Dynamic modules not supported on this platform);
 #endif
 
-config_add_mib(UCD-DLMOD-MIB)
+config_add_mib(UCD-DLMOD-MIB);
 
 void init_dlmod(void);
 void shutdown_dlmod(void);
