@@ -3,7 +3,7 @@
 #include <ctype.h>
 #include <stddef.h>
 #include <stdio.h>
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
