@@ -4,15 +4,15 @@
 #ifdef HAVE_IO_H
 #include <io.h>
 #endif
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <ctype.h>
@@ -452,7 +452,7 @@ setPassPersist(int action,
             netsnmp_internal_pass_set_format(buf2, var_val, var_val_type,
                                              var_val_len);
             free(persistpassthru->command);
-            if (asprintf(&persistpassthru->command, "set\n%s\n%s\n", buf,
+            if (asprintf(&persistpassthru->command, "set\n%s\n%s", buf,
                          buf2) < 0) {
                 persistpassthru->command = NULL;
                 return SNMP_ERR_GENERR;
