@@ -5,7 +5,7 @@
 #ifndef _MIBGROUP_VMSTAT_H
 #define _MIBGROUP_VMSTAT_H
 
-config_require(hardware/cpu)
+config_require(hardware/cpu);
 
 #include "mibdefs.h"
 
