@@ -2,7 +2,7 @@
  * @brief winExtDLL Net-SNMP agent extension module.
  *
  * Copyright (c) 2006-2009 Alex Burger.
- * Copyright (c) 2009-2010 Bart Van Assche <bart.vanassche@gmail.com>.
+ * Copyright (c) 2009-2021 Bart Van Assche <bart.vanassche@gmail.com>.
  *
  * This Net-SNMP agent extension module loads Windows SNMP Extension Agent
  * DLLs in the Net-SNMP agent. Not only extension DLLs provided with Windows
@@ -291,6 +291,7 @@ static void    *xarray_reserve(xarray * a, int reserved);
 #define TRAPEVENT(i)            ((HANDLE*)s_trapevent.p)[i]
 #define TRAPEVENT_TO_DLLINFO(i) ((winextdll**)s_trapevent_to_dllinfo.p)[i]
 static const oid mibii_system_mib[] = { 1, 3, 6, 1, 2, 1, 1 };
+static const oid lmmib2_mib[] = { 1, 3, 6, 1, 4, 1, 77 };
 static OSVERSIONINFO s_versioninfo = { sizeof(s_versioninfo) };
 static xarray   s_winextdll = { 0, sizeof(winextdll) };
 static xarray   s_winextdll_view = { 0, sizeof(winextdll_view) };
@@ -338,11 +339,29 @@ init_winExtDLL(void)
         winextdll      *const ext_dll_info = &WINEXTDLL(i);
         AsnObjectIdentifier view;
         winextdll_view  ext_dll_view_info;
+        const char *dll_basename, *last_slash, *last_backslash;
 
         netsnmp_assert(ext_dll_info);
         if (!ext_dll_info->dll_name)
             continue;
 
+        last_slash = strrchr(ext_dll_info->dll_name, '/');
+        last_backslash = strrchr(ext_dll_info->dll_name, '\\');
+        if (last_slash && last_backslash)
+            dll_basename = last_slash > last_backslash ? last_slash + 1:
+                last_backslash + 1;
+        else if (last_slash)
+            dll_basename = last_slash + 1;
+        else if (last_backslash)
+            dll_basename = last_backslash + 1;
+        else
+            dll_basename = ext_dll_info->dll_name;
+        DEBUGMSG(("winExtDLL", "dll_basename = %s\n", dll_basename));
+        if (!should_init(dll_basename)) {
+            DEBUGMSG(("winExtDLL", "Skipping DLL %s.\n",
+                      ext_dll_info->dll_name));
+            continue;
+        }
         DEBUGMSG(("winExtDLL", "loading DLL %s.\n",
                   ext_dll_info->dll_name));
         ext_dll_info->dll_handle = LoadLibrary(ext_dll_info->dll_name);
@@ -366,8 +385,7 @@ init_winExtDLL(void)
                     *p = '\0';
             }
             snmp_log(LOG_ERR,
-                     "init_winExtDLL: could not load SNMP extension"
-                     " DLL %s: %s\n",
+                     "init_winExtDLL: could not load SNMP extension DLL %s: %s\n",
                      ext_dll_info->dll_name, lpMsgBuf ? lpMsgBuf : "(?)");
             if (lpMsgBuf)
                 LocalFree(lpMsgBuf);
@@ -381,16 +399,14 @@ init_winExtDLL(void)
             GetProcAddress(ext_dll_info->dll_handle, "SnmpExtensionInit");
         ext_dll_info->pfSnmpExtensionInitEx =
 	    (PFNSNMPEXTENSIONINITEX)(uintptr_t)
-            GetProcAddress(ext_dll_info->dll_handle,
-                           "SnmpExtensionInitEx");
+            GetProcAddress(ext_dll_info->dll_handle, "SnmpExtensionInitEx");
         ext_dll_info->pfSnmpExtensionClose = (PFNSNMPEXTENSIONCLOSE)
             GetProcAddress(ext_dll_info->dll_handle, "SnmpExtensionClose");
         ext_dll_info->pfSnmpExtensionQuery = (PFNSNMPEXTENSIONQUERY)(uintptr_t)
             GetProcAddress(ext_dll_info->dll_handle, "SnmpExtensionQuery");
         ext_dll_info->pfSnmpExtensionQueryEx =
 	    (PFNSNMPEXTENSIONQUERYEX)(uintptr_t)
-            GetProcAddress(ext_dll_info->dll_handle,
-                           "SnmpExtensionQueryEx");
+            GetProcAddress(ext_dll_info->dll_handle, "SnmpExtensionQueryEx");
         ext_dll_info->pfSnmpExtensionTrap = (PFNSNMPEXTENSIONTRAP)(uintptr_t)
             GetProcAddress(ext_dll_info->dll_handle, "SnmpExtensionTrap");
 
@@ -402,21 +418,6 @@ init_winExtDLL(void)
                      ext_dll_info->dll_name);
         }
 
-        /*
-         * At least on a 64-bit Windows 7 system invoking SnmpExtensionInit()
-         * in the 32-bit version of evntagnt.dll hangs. Also, all queries in
-         * lmmib2.dll fail with "generic error" on a 64-bit Windows 7 system.
-         * So skip these two DLLs.
-         */
-        if (s_versioninfo.dwMajorVersion >= 6
-            && ((is_wow64_process
-                 && basename_equals(ext_dll_info->dll_name, "evntagnt.dll"))
-                || basename_equals(ext_dll_info->dll_name, "lmmib2.dll"))) {
-            DEBUGMSG(("winExtDLL", "init_winExtDLL: skipped DLL %s.\n",
-                      ext_dll_info->dll_name));
-            continue;
-        }
-
         /*
          * Init and get first supported view from Windows SNMP extension DLL.
          * Note: although according to the documentation of SnmpExtensionInit()
@@ -454,25 +455,10 @@ init_winExtDLL(void)
                   "init_winExtDLL: DLL %s view length %d\n",
                   ext_dll_info->dll_name, view.idLength));
         if (view.idLength) {
-            /*
-             * Skip the mib-2 system section on Windows Vista and later because
-             * at least on a 64-bit Windows 7 system all queries in that section
-             * fail with status "generic error".
-             */
-            if (s_versioninfo.dwMajorVersion >= 6
-                && snmp_oid_compare_w_n(view.ids, view.idLength,
-                                        mibii_system_mib,
-                                        sizeof(mibii_system_mib) /
-                                        sizeof(mibii_system_mib[0])) == 0) {
-                DEBUGMSG(("winExtDLL",
-                          "init_winExtDLL: skipping system section of DLL %s.\n",
-                          ext_dll_info->dll_name));
-            } else {
-                copy_oid_n_w(ext_dll_view_info.name,
-                             &ext_dll_view_info.name_length,
-                             view.ids, view.idLength);
-                xarray_push_back(&s_winextdll_view, &ext_dll_view_info);
-            }
+            copy_oid_n_w(ext_dll_view_info.name,
+                         &ext_dll_view_info.name_length,
+                         view.ids, view.idLength);
+            xarray_push_back(&s_winextdll_view, &ext_dll_view_info);
         }
 
         /*
@@ -631,7 +617,7 @@ register_netsnmp_handler(winextdll_view * const ext_dll_view_info)
         memset(ext_dll_view_info, 0, sizeof(*ext_dll_view_info));
         return 1;
     } else {
-        // Create handler registration
+        /* Create handler registration */
         ext_dll_view_info->my_handler
             = netsnmp_create_handler_registration(ext_dll_info->dll_name,
                                                   var_winExtDLL,
@@ -658,7 +644,9 @@ register_netsnmp_handler(winextdll_view * const ext_dll_view_info)
                 }
                 return 1;
             } else {
-                snmp_log(LOG_ERR, "handler registration failed.\n");
+                snmp_log(LOG_ERR,
+                         "winExtDLL: handler registration failed for %s.\n",
+                         ext_dll_info->dll_name);
                 ext_dll_view_info->my_handler = 0;
             }
         } else {
@@ -870,14 +858,15 @@ var_winExtDLL(netsnmp_mib_handler *handler,
         varbind = request->requestvb;
         netsnmp_assert(varbind);
 
+retry:
         /*
          * Convert the Net-SNMP varbind to a Windows SNMP varbind list.
          */
         rc = convert_to_windows_varbind_list(&win_varbinds, varbind);
         if (rc != SNMP_ERR_NOERROR) {
             DEBUGMSG(("winExtDLL",
-                      "converting varbind list to Windows format failed with"
-                      " error code %d.\n", request->status));
+                      "converting varbind list to Windows format failed with error code %d.\n",
+                      request->status));
             netsnmp_request_set_error(requests, rc);
             goto free_win_varbinds;
         }
@@ -956,6 +945,10 @@ var_winExtDLL(netsnmp_mib_handler *handler,
 
         rc = convert_win_snmp_err(ErrorStatus);
         if (rc != SNMP_ERR_NOERROR) {
+            copy_oid_n_w(varbind->name, &varbind->name_length,
+                         win_varbinds.list[0].name.ids,
+                         win_varbinds.list[0].name.idLength);
+
             DEBUGIF("winExtDLL") {
                 size_t          oid_namelen = 0, outlen = 0;
                 char           *oid_name = NULL;
@@ -964,24 +957,40 @@ var_winExtDLL(netsnmp_mib_handler *handler,
                 netsnmp_sprint_realloc_objid((u_char **) & oid_name,
                                              &oid_namelen,
                                              &outlen, 1, &overflow,
-                                             ext_dll_view_info->name,
-                                             ext_dll_view_info->name_length);
-                DEBUGMSG(("winExtDLL", "extension DLL %s: SNMP query function"
-                          " returned error code %lu (Windows) / %d (Net-SNMP)"
-                          " for request type %d, OID %s%s, ASN type %d and"
-                          " value %ld.\n",
-                          ext_dll_info->dll_name, ErrorStatus, rc, nRequestType,
-                          oid_name, overflow ? " [TRUNCATED]" : "",
+                                             varbind->name,
+                                             varbind->name_length);
+                DEBUGMSG(("winExtDLL",
+                          "extension DLL %s: SNMP query function returned error code %u (Windows) / %d (Net-SNMP) for request type %d, OID %s%s, ASN type %d and value %d.\n",
+                          ext_dll_info->dll_name, (unsigned int)ErrorStatus, rc,
+                          nRequestType, oid_name,
+                          overflow ? " [TRUNCATED]" : "",
                           win_varbinds.list[0].value.asnType,
-                          win_varbinds.list[0].value.asnValue.number));
+                          (unsigned int)win_varbinds.list[0].value.asnValue.number));
                 free(oid_name);
             }
             netsnmp_assert(ErrorIndex == 1);
-            netsnmp_request_set_error(requests, rc);
-            if (rc == SNMP_NOSUCHOBJECT || rc == SNMP_NOSUCHINSTANCE
-                || rc == SNMP_ERR_NOSUCHNAME)
-                rc = SNMP_ERR_NOERROR;
-            goto free_win_varbinds;
+            if (rc == SNMP_ERR_GENERR &&
+                reqinfo->mode == MODE_GETNEXT &&
+                varbind->name_length > 0 &&
+                (snmp_oid_compare(varbind->name, varbind->name_length,
+                                  mibii_system_mib,
+                                  sizeof(mibii_system_mib) /
+                                  sizeof(mibii_system_mib[0])) == 0 ||
+                 snmp_oidtree_compare(varbind->name, varbind->name_length,
+				      lmmib2_mib,
+				      sizeof(lmmib2_mib) /
+				      sizeof(lmmib2_mib[0])) == 0)) {
+                // Quirk: ignore 'generic error' for the MIB-II system MIB OID.
+                DEBUGMSG(("winExtDLL", "Ignoring the above error\n"));
+                varbind->name[varbind->name_length - 1]++;
+                goto retry;
+            } else {
+                netsnmp_request_set_error(requests, rc);
+                if (rc == SNMP_NOSUCHOBJECT || rc == SNMP_NOSUCHINSTANCE ||
+                    rc == SNMP_ERR_NOSUCHNAME)
+                    rc = SNMP_ERR_NOERROR;
+                goto free_win_varbinds;
+            }
         }
 
         copy_value = FALSE;
@@ -1141,10 +1150,7 @@ read_extension_dll_path_from_registry(const TCHAR * keyName)
     if (retCode != ERROR_SUCCESS)
         return 0;
 
-    retCode = RegQueryValueExA(hKey,
-                               "Pathname",
-                               NULL,
-                               &key_value_type,
+    retCode = RegQueryValueExA(hKey, "Pathname", NULL, &key_value_type,
                                (BYTE *) valueName, &key_value_size);
 
     if (retCode != ERROR_SUCCESS) {
@@ -1204,8 +1210,7 @@ subagentTrapCheck(unsigned int clientreg, void *clientarg)
 
         if (!ext_dll_info->pfSnmpExtensionTrap) {
             snmp_log(LOG_ERR,
-                     "internal error in SNMP extension DLL %s: a trap is ready"
-                     " but the function SnmpExtensionTrap() is missing.\n",
+                     "internal error in SNMP extension DLL %s: a trap is ready but the function SnmpExtensionTrap() is missing.\n",
                      ext_dll_info->dll_name);
             return;
         }
@@ -1455,7 +1460,7 @@ append_windows_varbind(netsnmp_variable_list ** const net_snmp_varbinds,
                                     sizeof(win_varbind->value.asnValue.
                                            ticks));
         break;
-    case MS_ASN_OPAQUE:        // AsnOctetString
+    case MS_ASN_OPAQUE:        /* AsnOctetString */
         snmp_varlist_add_variable_w(net_snmp_varbinds, win_varbind->name.ids,
                                     win_varbind->name.idLength,
                                     ASN_OPAQUE,
@@ -1541,7 +1546,7 @@ convert_to_windows_varbind_list(SnmpVarBindList * pVarBindList,
 
     switch (varbind->type) {
     case ASN_BOOLEAN:
-        // There is no equivalent type in Microsoft's <snmp.h>.
+        /* There is no equivalent type in Microsoft's <snmp.h>. */
         netsnmp_assert(0);
         win_varbind->value.asnType = MS_ASN_INTEGER;
         win_varbind->value.asnValue.number = *(varbind->val.integer);
@@ -1586,7 +1591,7 @@ convert_to_windows_varbind_list(SnmpVarBindList * pVarBindList,
         win_varbind->value.asnValue.string.dynamic = TRUE;
         break;
     case ASN_SET:
-        // There is no equivalent type in Microsoft's <snmp.h>.
+        /* There is no equivalent type in Microsoft's <snmp.h>. */
         netsnmp_assert(0);
         win_varbind->value.asnType = MS_ASN_INTEGER;
         win_varbind->value.asnValue.number = *(varbind->val.integer);
