@@ -26,10 +26,10 @@
 #include <ctype.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
@@ -83,7 +83,7 @@ char           *newpass = NULL, *oldpass = NULL;
 char           *transform_type_input = NULL;
 
 const oid      *transform_type = NULL;  /* Type of HMAC hash to use.      */
-
+size_t          transform_type_len = 0;
 
 
 /*
@@ -95,12 +95,12 @@ int             get_user_passphrases(void);
 int             snmp_ttyecho(const int fd, const int echo);
 char           *snmp_getpassphrase(const char *prompt, int fvisible);
 
-#ifdef WIN32
+#if defined(HAVE__CPUTS) && defined(HAVE__GETCH)
+#include <conio.h>
+#include <io.h>
 #define HAVE_GETPASS 1
-char           *getpass(const char *prompt);
-int             isatty(int);
-int             _cputs(const char *);
-int             _getch(void);
+#define isatty _isatty
+static char    *getpass(const char *prompt);
 #endif
 
 /*******************************************************************-o-******
@@ -108,7 +108,7 @@ int             _getch(void);
 int
 main(int argc, char **argv)
 {
-    int             rval = SNMPERR_SUCCESS;
+    int             rval = 1;
     size_t          oldKu_len = SNMP_MAXBUF_SMALL,
         newKu_len = SNMP_MAXBUF_SMALL,
         oldkul_len = SNMP_MAXBUF_SMALL,
@@ -120,7 +120,7 @@ main(int argc, char **argv)
         oldkul[SNMP_MAXBUF_SMALL],
         newkul[SNMP_MAXBUF_SMALL], keychange[SNMP_MAXBUF_SMALL];
 
-    int             i;
+    int             i, auth_type;
     int             arg = 1;
 
     local_progname = argv[0];
@@ -170,6 +170,7 @@ main(int argc, char **argv)
             break;
         case 'h':
             rval = 0;
+	    /* fallthrough */
         default:
             usage_to_file(stdout);
             exit(rval);
@@ -187,31 +188,18 @@ main(int argc, char **argv)
     /*
      * Convert and error check transform_type.
      */
-#ifndef NETSNMP_DISABLE_MD5
-    if (!strcmp(transform_type_input, "md5")) {
-        transform_type = usmHMACMD5AuthProtocol;
-
-    } else
-#endif
-        if (!strcmp(transform_type_input, "sha1")) {
-        transform_type = usmHMACSHA1AuthProtocol;
-
-    } else {
+    auth_type = usm_lookup_auth_type(transform_type_input);
+    transform_type = sc_get_auth_oid( auth_type, &transform_type_len );
+    if (NULL == transform_type) {
         fprintf(stderr,
                 "Unrecognized hash transform: \"%s\".\n",
                 transform_type_input);
         usage_synopsis(stderr);
-        QUITFUN(rval = SNMPERR_GENERR, main_quit);
+        QUITFUN(SNMPERR_GENERR, main_quit);
     }
 
     if (verbose) {
-        fprintf(stderr, "Hash:\t\t%s\n",
-#ifndef NETSNMP_DISABLE_MD5
-                (transform_type == usmHMACMD5AuthProtocol)
-                ? "usmHMACMD5AuthProtocol" :
-#endif
-                "usmHMACSHA1AuthProtocol"
-            );
+        fprintf(stderr, "Hash:\t\t%s\n", sc_get_auth_name(auth_type));
     }
 
 
@@ -232,7 +220,8 @@ main(int argc, char **argv)
                     (unsigned long)engineid_len));
     } else {
         engineid_len = setup_engineID(&engineid, (char *) engineid);
-
+        if ((ssize_t)engineid_len < 0)
+            exit(1);
     }
 
 #ifdef NETSNMP_ENABLE_TESTING_CODE
@@ -254,12 +243,12 @@ main(int argc, char **argv)
     if (strlen(oldpass) < USM_LENGTH_P_MIN) {
         fprintf(stderr, "Old passphrase must be greater than %d "
                 "characters in length.\n", USM_LENGTH_P_MIN);
-        QUITFUN(rval = SNMPERR_GENERR, main_quit);
+        QUITFUN(SNMPERR_GENERR, main_quit);
 
     } else if (strlen(newpass) < USM_LENGTH_P_MIN) {
         fprintf(stderr, "New passphrase must be greater than %d "
                 "characters in length.\n", USM_LENGTH_P_MIN);
-        QUITFUN(rval = SNMPERR_GENERR, main_quit);
+        QUITFUN(SNMPERR_GENERR, main_quit);
     }
 
     if (verbose) {
@@ -278,13 +267,13 @@ main(int argc, char **argv)
     QUITFUN(rval, main_quit);
 
 
-    rval = generate_Ku(transform_type, USM_LENGTH_OID_TRANSFORM,
+    rval = generate_Ku(transform_type, transform_type_len,
                        (u_char *) oldpass, strlen(oldpass),
                        oldKu, &oldKu_len);
     QUITFUN(rval, main_quit);
 
 
-    rval = generate_Ku(transform_type, USM_LENGTH_OID_TRANSFORM,
+    rval = generate_Ku(transform_type, transform_type_len,
                        (u_char *) newpass, strlen(newpass),
                        newKu, &newKu_len);
     QUITFUN(rval, main_quit);
@@ -301,7 +290,7 @@ main(int argc, char **argv)
         DEBUGMSGTL(("encode_keychange", "%02x", (int) (oldKu[i])));
     DEBUGMSGTL(("encode_keychange", "\n"));
 
-    rval = generate_kul(transform_type, USM_LENGTH_OID_TRANSFORM,
+    rval = generate_kul(transform_type, transform_type_len,
                         engineid, engineid_len,
                         oldKu, oldKu_len, oldkul, &oldkul_len);
     QUITFUN(rval, main_quit);
@@ -313,7 +302,7 @@ main(int argc, char **argv)
         DEBUGMSGTL(("encode_keychange", "%02x", (int) (oldkul[i])));
     DEBUGMSGTL(("encode_keychange", "\n"));
 
-    rval = generate_kul(transform_type, USM_LENGTH_OID_TRANSFORM,
+    rval = generate_kul(transform_type, transform_type_len,
                         engineid, engineid_len,
                         newKu, newKu_len, newkul, &newkul_len);
     QUITFUN(rval, main_quit);
@@ -324,7 +313,7 @@ main(int argc, char **argv)
         DEBUGMSGTL(("encode_keychange", "%02x", newkul[i]));
     DEBUGMSGTL(("encode_keychange", "\n"));
 
-    rval = encode_keychange(transform_type, USM_LENGTH_OID_TRANSFORM,
+    rval = encode_keychange(transform_type, transform_type_len,
                             oldkul, oldkul_len,
                             newkul, newkul_len, keychange, &keychange_len);
     QUITFUN(rval, main_quit);
@@ -402,7 +391,7 @@ usage_to_file(FILE * ofp)
    "-f will require reading from the stdin/terminal, ignoring a) and b).\n\
     -P will prevent prompts for passphrases to stdout from being printed.\n\
 \n\
-    <engineID> is interpreted as a hex string when preceeded by \"0x\",\n\
+    <engineID> is interpreted as a hex string when preceded by \"0x\",\n\
     otherwise it is created to contain \"text\".  If nothing is given,\n\
     <engineID> is constructed from the first IP address for the local host.\n");
 
@@ -503,13 +492,13 @@ get_user_passphrases(void)
      */
     if (stat(path, &statbuf) < 0) {
         fprintf(stderr, "Cannot access directory \"%s\".\n", path);
-        QUITFUN(rval = SNMPERR_GENERR, get_user_passphrases_quit);
+        QUITFUN(SNMPERR_GENERR, get_user_passphrases_quit);
 #ifndef WIN32
     } else if (statbuf.st_mode & (S_IRWXG | S_IRWXO)) {
         fprintf(stderr,
                 "Directory \"%s\" is accessible by group or world.\n",
                 path);
-        QUITFUN(rval = SNMPERR_GENERR, get_user_passphrases_quit);
+        QUITFUN(SNMPERR_GENERR, get_user_passphrases_quit);
 #endif                          /* !WIN32 */
     }
 
@@ -520,12 +509,12 @@ get_user_passphrases(void)
     path[ sizeof(path)-1 ] = 0;
     if (stat(path, &statbuf) < 0) {
         fprintf(stderr, "Cannot access file \"%s\".\n", path);
-        QUITFUN(rval = SNMPERR_GENERR, get_user_passphrases_quit);
+        QUITFUN(SNMPERR_GENERR, get_user_passphrases_quit);
 #ifndef WIN32
     } else if (statbuf.st_mode & (S_IRWXG | S_IRWXO)) {
         fprintf(stderr,
                 "File \"%s\" is accessible by group or world.\n", path);
-        QUITFUN(rval = SNMPERR_GENERR, get_user_passphrases_quit);
+        QUITFUN(SNMPERR_GENERR, get_user_passphrases_quit);
 #endif                          /* !WIN32 */
     }
 
@@ -534,7 +523,7 @@ get_user_passphrases(void)
      */
     if ((fp = fopen(path, "r")) == NULL) {
         fprintf(stderr, "Cannot open \"%s\".", path);
-        QUITFUN(rval = SNMPERR_GENERR, get_user_passphrases_quit);
+        QUITFUN(SNMPERR_GENERR, get_user_passphrases_quit);
     }
 
     /*
@@ -548,7 +537,7 @@ get_user_passphrases(void)
 
     } else if (!oldpass) {
         len = strlen(buf);
-        if (buf[len - 1] == '\n')
+        if (len && buf[len - 1] == '\n')
             buf[--len] = '\0';
         oldpass = (char *) calloc(1, len + 1);
         if (oldpass)
@@ -564,7 +553,7 @@ get_user_passphrases(void)
 
     } else if (!newpass) {
         len = strlen(buf);
-        if (buf[len - 1] == '\n')
+        if (len && buf[len - 1] == '\n')
             buf[--len] = '\0';
         newpass = (char *) calloc(1, len + 1);
         if (newpass)
@@ -755,7 +744,7 @@ snmp_getpassphrase(const char *prompt, int bvisible)
      * Copy the input and zero out the read-in buffer.
      */
     len = strlen(buffer);
-    if (buffer[len - 1] == '\n')
+    if (len && buffer[len - 1] == '\n')
         buffer[--len] = '\0';
 
     bufp = (char *) calloc(1, len + 1);
@@ -769,8 +758,7 @@ snmp_getpassphrase(const char *prompt, int bvisible)
 
 }                               /* end snmp_getpassphrase() */
 
-#ifdef WIN32
-
+#if defined(HAVE__CPUTS) && defined(HAVE__GETCH)
 int
 snmp_ttyecho(const int fd, const int echo)
 {
@@ -781,7 +769,7 @@ snmp_ttyecho(const int fd, const int echo)
  * stops at the first newline, carrier return, or backspace.
  * WARNING! _getch does NOT read <Ctrl-C>
  */
-char           *
+static char    *
 getpass(const char *prompt)
 {
     static char     pbuf[128];
@@ -799,4 +787,4 @@ getpass(const char *prompt)
 
     return pbuf;
 }
-#endif                          /* WIN32 */
+#endif /* defined(HAVE__CPUTS) && defined(HAVE__GETCH) */
