@@ -17,7 +17,7 @@
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
-#if HAVE_SYS_UN_H
+#ifdef HAVE_SYS_UN_H
 #include <sys/un.h>
 #endif
 
@@ -123,24 +123,29 @@ main(int argc, char **argv) {
     /* send the prelim message and the credentials together using sendmsg() */
     {
         struct msghdr m;
-        struct {
-           struct cmsghdr cm;
-           struct ucred ouruser;
+        /*
+         * Ancillary data buffer, wrapped in a union in order to ensure it is
+         * suitably aligned.
+         */
+        union {
+            char buf[CMSG_SPACE(sizeof(struct ucred))];
+            struct cmsghdr cm;
         } cmsg;
+        struct ucred *const ouruser = (void *)CMSG_DATA(&cmsg.cm);
         struct iovec iov = { buf, buf_len };
 
         /* Make sure that even padding fields get initialized.*/
         memset(&cmsg, 0, sizeof(cmsg));
         memset(&m, 0, sizeof(m));
 
-        /* set up the basic message */
-        cmsg.cm.cmsg_len = sizeof(struct cmsghdr) + sizeof(struct ucred);
+        /* set up the message header */
+        cmsg.cm.cmsg_len = sizeof(cmsg);
         cmsg.cm.cmsg_level = SOL_SOCKET;
         cmsg.cm.cmsg_type = SCM_CREDENTIALS;
 
-        cmsg.ouruser.uid = getuid();
-        cmsg.ouruser.gid = getgid();
-        cmsg.ouruser.pid = getpid();
+        ouruser->uid = getuid();
+        ouruser->gid = getgid();
+        ouruser->pid = getpid();
 
         m.msg_iov               = &iov;
         m.msg_iovlen            = 1;
