@@ -1,13 +1,10 @@
-#!/bin/bash
+#!/bin/sh
 
-# Instead of relying on the hosts file provided by the CI host, replace it.
-# See also
-# https://blog.justincarmony.com/2011/07/27/mac-os-x-lion-etc-hosts-bugs-and-dns-resolution/.
-sudo sh -c 'printf "127.0.0.1 ipv4-loopback\n::1 localhost ipv6-localhost ipv6-loopback\n" >/etc/hosts'
+scriptdir="$(cd "$(dirname "$0")" && pwd)"
 
 case "$(uname)" in
     Linux)
-	packages=(
+	packages="
 	    libatm1-dev
 	    libkrb5-dev
 	    libmariadb-client-lgpl-dev
@@ -25,10 +22,13 @@ case "$(uname)" in
 	    make
 	    pkg-config
 	    python3-dev
-	)
-	for p in "${packages[@]}"; do
-	    sh -c "apt-get -qq install -y $p"
+	    setpriv
+	"
+	apt-get update
+	for p in ${packages}; do
+	    apt-get install -qq -o=Dpkg::Use-Pty=0 -y "$p"
 	done
+	true
 	;;
     Darwin)
 	# Upgrade openssl such that Net-SNMP can be built with Blumenthal
@@ -45,7 +45,7 @@ case "$(uname)" in
 	pkg install -y libssh2
 	#pkg install -y openssl111
 	pkg install -y perl5 perl5-devel p5-ExtUtils-MakeMaker
-	pkg install -y pkgconf
+	#pkg install -y pkgconf
 	pkg install -y py27-setuptools
 	if [ ! -e /usr/bin/perl ]; then
 	    ln -s /usr/local/bin/perl /usr/bin/perl
@@ -53,4 +53,20 @@ case "$(uname)" in
 	;;
 esac
 
-head -n 999 /etc/hosts
+case "$MODE" in
+    wolfssl)
+	if [ -n "$SUDO_UID" ] && [ -n "$SUDO_GID" ]; then
+	    if type setpriv >/dev/null 2>&1; then
+		setpriv --reuid="$SUDO_UID" --regid="$SUDO_GID" --init-groups \
+			--inh-caps=-CHOWN,-SETUID,-SETGID \
+			"${scriptdir}/wolfssl.sh"
+	    elif [ -n "${SUDO_USER}" ]; then
+		sudo -u "${SUDO_USER}" "${scriptdir}/wolfssl.sh"
+	    else
+		"${scriptdir}/wolfssl.sh"
+	    fi
+	else
+	    "${scriptdir}/wolfssl.sh"
+	fi
+	;;
+esac
