@@ -8,11 +8,11 @@
 #ifdef HAVE_SYS_TIMEB_H
 # include <sys/timeb.h> /* _ftime() */
 #endif
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
