@@ -69,26 +69,26 @@
 
 #include <stdio.h>
 #include <ctype.h>
-#if HAVE_STDLIB_H
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <sys/types.h>
-#if HAVE_SYS_PARAM_H
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
@@ -117,19 +117,19 @@
 #include <io.h>
 #endif
 
-#if HAVE_DIRENT_H
+#ifdef HAVE_DIRENT_H
 # include <dirent.h>
 # define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
 # define dirent direct
 # define NAMLEN(dirent) (dirent)->d_namlen
-# if HAVE_SYS_NDIR_H
+# ifdef HAVE_SYS_NDIR_H
 #  include <sys/ndir.h>
 # endif
-# if HAVE_SYS_DIR_H
+# ifdef HAVE_SYS_DIR_H
 #  include <sys/dir.h>
 # endif
-# if HAVE_NDIR_H
+# ifdef HAVE_NDIR_H
 #  include <ndir.h>
 # endif
 #endif
@@ -842,7 +842,7 @@ read_config(const char *filename,
 
             linelen += strlen(line + linelen);
 
-            if (line[linelen - 1] == '\n') {
+            if (linelen && line[linelen - 1] == '\n') {
               line[linelen - 1] = '\0';
               break;
             }
@@ -2017,7 +2017,7 @@ read_config_read_octet_string_const(const char *readfrom, u_char ** str,
         if (ilen % 2) {
             snmp_log(LOG_WARNING,"invalid hex string: wrong length\n");
             DEBUGMSGTL(("read_config_read_octet_string",
-                        "invalid hex string: wrong length"));
+                        "invalid hex string: wrong length\n"));
             return NULL;
         }
         ilen = ilen / 2;
@@ -2037,7 +2037,7 @@ read_config_read_octet_string_const(const char *readfrom, u_char ** str,
                 snmp_log(LOG_WARNING,"buffer too small to read octet string (%lu < %lu)\n",
                          (unsigned long)*len, (unsigned long)ilen);
                 DEBUGMSGTL(("read_config_read_octet_string",
-                            "buffer too small (%lu < %lu)", (unsigned long)*len, (unsigned long)ilen));
+                            "buffer too small (%lu < %lu)\n", (unsigned long)*len, (unsigned long)ilen));
                 *len = 0;
                 cptr1 = skip_not_white_const(readfrom);
                 return skip_white_const(cptr1);
@@ -2153,7 +2153,7 @@ read_config_read_objid_const(const char *readfrom, oid ** objid, size_t * len)
         copy_nword_const(readfrom, buf, sizeof(buf));
 
         if (!read_objid(buf, *objid, len)) {
-            DEBUGMSGTL(("read_config_read_objid", "Invalid OID"));
+            DEBUGMSGTL(("read_config_read_objid", "Invalid OID\n"));
             *len = 0;
             return NULL;
         }
@@ -2232,7 +2232,7 @@ read_config_read_data(int type, char *readfrom, void *dataptr,
             return read_config_read_objid(readfrom, oidpp, len);
 
         default:
-            DEBUGMSGTL(("read_config_read_data", "Fail: Unknown type: %d",
+            DEBUGMSGTL(("read_config_read_data", "Fail: Unknown type: %d\n",
                         type));
             return NULL;
         }
@@ -2311,7 +2311,7 @@ read_config_read_memory(int type, char *readfrom,
         return readfrom;
     }
 
-    DEBUGMSGTL(("read_config_read_memory", "Fail: Unknown type: %d", type));
+    DEBUGMSGTL(("read_config_read_memory", "Fail: Unknown type: %d\n", type));
     return NULL;
 }
 
@@ -2390,7 +2390,7 @@ read_config_store_data_prefix(char prefix, int type, char *storeto,
 
         default:
             DEBUGMSGTL(("read_config_store_data_prefix",
-                        "Fail: Unknown type: %d", type));
+                        "Fail: Unknown type: %d\n", type));
             return NULL;
         }
     return NULL;
