@@ -29,16 +29,16 @@
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
 #endif
-#if TIME_WITH_SYS_TIME
+#ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
 #else
-# if HAVE_SYS_TIME_H
+# ifdef HAVE_SYS_TIME_H
 #  include <sys/time.h>
 # else
 #  include <time.h>
@@ -48,7 +48,7 @@
 #include <netinet/in.h>
 #endif
 
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include "memcheck.h"
@@ -65,6 +65,7 @@ netsnmp_feature_child_of(usm_scapi, usm_support);
 #ifdef NETSNMP_USE_INTERNAL_MD5
 #include <net-snmp/library/md5.h>
 #endif
+#include <net-snmp/library/openssl_config.h>
 #include <net-snmp/library/snmp_api.h>
 #include <net-snmp/library/callback.h>
 #include <net-snmp/library/snmp_secmod.h>
@@ -554,7 +555,7 @@ sc_init(void)
     gettimeofday(&tv, (struct timezone *) 0);
 
     netsnmp_srandom((unsigned)(tv.tv_sec ^ tv.tv_usec));
-#elif NETSNMP_USE_PKCS11
+#elif defined(NETSNMP_USE_PKCS11)
     DEBUGTRACE;
     rval = pkcs_init();
 #else
@@ -595,7 +596,7 @@ sc_random(u_char * buf, size_t * buflen)
 #ifdef NETSNMP_USE_OPENSSL
     RAND_bytes(buf, *buflen);   /* will never fail */
     MAKE_MEM_DEFINED(buf, *buflen);
-#elif NETSNMP_USE_PKCS11			/* NETSNMP_USE_PKCS11 */
+#elif defined(NETSNMP_USE_PKCS11)  /* NETSNMP_USE_PKCS11 */
     pkcs_random(buf, *buflen);
 #else                           /* NETSNMP_USE_INTERNAL_MD5 */
     /*
@@ -789,7 +790,7 @@ sc_generate_keyed_hash(const oid * authtypeOID, size_t authtypeOIDlen,
         *maclen = buf_len;
     memcpy(MAC, buf, *maclen);
 
-#elif NETSNMP_USE_PKCS11                    /* NETSNMP_USE_PKCS11 */
+#elif defined(NETSNMP_USE_PKCS11)            /* NETSNMP_USE_PKCS11 */
 
 #ifndef NETSNMP_DISABLE_MD5
     if (NETSNMP_USMAUTH_HMACMD5 == auth_type) {
@@ -815,7 +816,7 @@ sc_generate_keyed_hash(const oid * authtypeOID, size_t authtypeOIDlen,
         *maclen = buf_len;
     memcpy(MAC, buf, *maclen);
 
-#elif NETSNMP_USE_INTERNAL_CRYPTO
+#elif defined(NETSNMP_USE_INTERNAL_CRYPTO)
     if (*maclen > properlength)
         *maclen = properlength;
 #ifndef NETSNMP_DISABLE_MD5
@@ -994,7 +995,7 @@ sc_hash_type_quit:
 #endif
     return (rval);
 
-#elif NETSNMP_USE_INTERNAL_CRYPTO
+#elif defined(NETSNMP_USE_INTERNAL_CRYPTO)
 #ifndef NETSNMP_DISABLE_MD5
     if (NETSNMP_USMAUTH_HMACMD5 == auth_type) {
         if (*MAC_len < MD5_DIGEST_LENGTH)
@@ -1017,7 +1018,7 @@ sc_hash_type_quit:
         return (SNMPERR_GENERR);
     }
     return (rval);
-#elif NETSNMP_USE_PKCS11                  /* NETSNMP_USE_PKCS11 */
+#elif defined(NETSNMP_USE_PKCS11)        /* NETSNMP_USE_PKCS11 */
 
 #ifndef NETSNMP_DISABLE_MD5
     if (NETSNMP_USMAUTH_HMACMD5 == auth_type) {
@@ -1580,7 +1581,7 @@ sc_decrypt(const oid * privtype, size_t privtypelen,
     memset(my_iv, 0, sizeof(my_iv));
     return rval;
 }				/* USE OPEN_SSL */
-#elif NETSNMP_USE_PKCS11                  /* USE PKCS */
+#elif defined(NETSNMP_USE_PKCS11)        /* USE PKCS */
 {
     int             rval = SNMPERR_SUCCESS;
     u_char	    pkcs_des_key[8];
