@@ -4,21 +4,21 @@
 
 netsnmp_feature_require(cert_util);
 
-#if HAVE_STRING_H
+#ifdef HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
 #endif
-#if HAVE_SYS_SOCKET_H
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
-#if HAVE_ARPA_INET_H
+#ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
-#if HAVE_NETDB_H
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
 #include <errno.h>
@@ -517,6 +517,7 @@ SSL_CTX *
 sslctx_client_setup(const SSL_METHOD *method, _netsnmpTLSBaseData *tlsbase) {
     netsnmp_cert *id_cert, *peer_cert;
     SSL_CTX      *the_ctx;
+    X509         *ocert;
 
     /***********************************************************************
      * Set up the client context
@@ -566,8 +567,13 @@ sslctx_client_setup(const SSL_METHOD *method, _netsnmpTLSBaseData *tlsbase) {
 
     while (id_cert->issuer_cert) {
         id_cert = id_cert->issuer_cert;
-        if (!SSL_CTX_add_extra_chain_cert(the_ctx, id_cert->ocert))
-            LOGANDDIE("failed to add intermediate client certificate");
+        if (id_cert->ocert)
+        {
+            ocert = X509_dup(id_cert->ocert);
+            DEBUGMSGTL(("sslctx_client", "adding cert-chain certificate %p", ocert));
+            if (!ocert || !SSL_CTX_add_extra_chain_cert(the_ctx, ocert))
+                LOGANDDIE("failed to add intermediate client certificate");
+        }
     }
 
     if (tlsbase->their_identity)
@@ -598,6 +604,7 @@ sslctx_client_setup(const SSL_METHOD *method, _netsnmpTLSBaseData *tlsbase) {
 SSL_CTX *
 sslctx_server_setup(const SSL_METHOD *method) {
     netsnmp_cert *id_cert;
+    X509         *ocert;
 
     /***********************************************************************
      * Set up the server context
@@ -632,8 +639,13 @@ sslctx_server_setup(const SSL_METHOD *method) {
 
     while (id_cert->issuer_cert) {
         id_cert = id_cert->issuer_cert;
-        if (!SSL_CTX_add_extra_chain_cert(the_ctx, id_cert->ocert))
-            LOGANDDIE("failed to add intermediate server certificate");
+        if (id_cert->ocert)
+        {
+            ocert = X509_dup(id_cert->ocert);
+            DEBUGMSGTL(("sslctx_server", "adding cert-chain certificate %p", ocert));
+            if (!ocert || !SSL_CTX_add_extra_chain_cert(the_ctx, ocert))
+                LOGANDDIE("failed to add intermediate server certificate");
+        }
     }
 
     SSL_CTX_set_read_ahead(the_ctx, 1); /* XXX: DTLS only? */
@@ -740,7 +752,7 @@ tls_bootstrap(int majorid, int minorid, void *serverarg, void *clientarg) {
 }
 
 int
-tls_get_verify_info_index() {
+tls_get_verify_info_index(void) {
     return openssl_local_index;
 }
 
